#! python3  # noqa: E265

"""Main CLI entrypoint."""

# standard lib
import argparse
from os import environ, getenv
from pathlib import Path

# 3rd party
from gpf_entrepot_toolbelt.__about__ import __package_name__ as toolbelt_pkg_name
from gpf_entrepot_toolbelt.orchestrator.check_livraison import check_livraison_structure
from gpf_entrepot_toolbelt.orchestrator.models import GpfOrchestratorParameters
from gpf_entrepot_toolbelt.orchestrator.status import Status
from gpf_entrepot_toolbelt.utils.cli_arguments_types import arg_type_path_folder
from gpf_entrepot_toolbelt.utils.database_inspection import PgDatabaseInspector
from gpf_entrepot_toolbelt.utils.environment import get_gdal_version, get_proj_version
from gpf_entrepot_toolbelt.utils.exit_program import fail_and_exit
from gpf_entrepot_toolbelt.utils.gpf_logger import gpf_logger_script

# package
from gpf_vector_to_db.__about__ import (
    __author__,
    __cli_usage__,
    __executable_name__,
    __package_name__,
    __summary__,
    __title__,
    __title_clean__,
    __uri_homepage__,
    __version__,
)
from gpf_vector_to_db.core import run
from gpf_vector_to_db.utils.vector_to_db import get_process_extent_from_parameters

# ############################################################################
# ########## MAIN ################
# ################################


def fail_and_exit_with_message(work_dir: Path, message: str):
    """
    Fail and exit process with a specified message

    Args:
        work_dir (Path): the current work directory
        message (str): The specific message to send

    """
    fail_and_exit(
        work_dir=work_dir,
        error_message=message,
        package_title=__title_clean__,
        package_version=__version__,
        package_exec_name=__executable_name__,
    )


def main(argv: list[str] = None):
    """Main CLI entrypoint."""
    # create the top-level parser
    parser = argparse.ArgumentParser(
        formatter_class=argparse.RawDescriptionHelpFormatter,
        epilog=f"{__cli_usage__}\n\n"
        f"Développé par {__author__}\n"
        f"Documentation : {__uri_homepage__}",
        description=f"{__title__} {__version__} - {__summary__}",
    )

    # -- ROOT ARGUMENTS --

    # Optional verbosity counter (eg. -v, -vv, -vvv, etc.)
    parser.add_argument(
        "-v",
        "--verbose",
        action="count",
        default=1,
        dest="verbosity",
        help="Verbosity level: None = WARNING, -v = INFO, -vv = DEBUG",
    )

    parser.add_argument(
        "--version",
        action="version",
        version=__version__,
    )

    # generic
    parser.add_argument(
        "-w",
        "--workdir",
        "--work-dir-path",
        dest="work_dir_path",
        type=arg_type_path_folder,
        help="Input working directory. Must exist.",
        default=getenv("GPF_WORK_DIR"),
    )

    parser.add_argument(
        "-u",
        "--uploaddir",
        "--upload-dir-name",
        dest="upload_dir_name",
        type=str,
        help="Name (not the path) of the upload directory.",
        default=getenv("GPF_UPLOAD_DIR", "upload"),
    )

    parser.add_argument(
        "-c",
        "--input-configuration-filename",
        dest="input_configuration_file_name",
        type=str,
        help="Name (not the path) of the input configuration file.",
        default=getenv("GPF_INPUT_CONFIGURATION_FILENAME", "parameters.json"),
    )

    # S3 configuration
    parser.add_argument(
        "--s3-url",
        metavar="GPF_S3_URL",
        dest="s3_url",
        type=str,
        help="Url du storage S3",
        default=getenv("GPF_S3_URL", "http://localhost:9000"),
    )

    parser.add_argument(
        "--s3-key",
        metavar="GPF_S3_KEY",
        dest="s3_key",
        type=str,
        help="Utilisateur du stockage S3",
        default=getenv("GPF_S3_KEY", "admin"),
    )

    parser.add_argument(
        "--s3-secret-key",
        metavar="GPF_S3_SECRETKEY",
        dest="s3_secret_key",
        type=str,
        help="Password du stockage S3",
        default=getenv("GPF_S3_SECRETKEY", "minioadmin"),
    )

    parser.add_argument(
        "--s3-region",
        metavar="GPF_S3_REGION",
        dest="s3_region",
        type=str,
        help="Region du stockage S3",
        default=getenv("GPF_S3_REGION", "eu-west-3"),
    )

    parser.add_argument(
        "-p",
        "--processing-type",
        dest="processing_type",
        metavar="PROCESSING_TYPE",
        type=str,
        help="Optionnal specific type of the processing in (GPU)",
        default=None,
    )

    # -- PARSE PASSED ARGUMENTS --

    # just get passed args
    args = parser.parse_args(argv)

    # set log level depending on verbosity argument
    if 0 < args.verbosity < 4:
        args.verbosity = 40 - (10 * args.verbosity)
    elif args.verbosity >= 4:
        # debug is the limit
        args.verbosity = 40 - (10 * 3)
    else:
        args.verbosity = 0

    # To have same level for toolbelt
    _ = gpf_logger_script(verbosity=args.verbosity, title=toolbelt_pkg_name)
    logger = gpf_logger_script(args.verbosity, __package_name__)
    logger.user_info(f"=== {__title__} {__version__} ===")
    logger.user_info(f"Version de GDAL : {get_gdal_version()}")
    logger.user_info(f"Version de PROJ : {get_proj_version()}")

    # Définition des variables d'environnement
    # Pour la toolbelt
    if args.s3_url:
        environ["GPF_S3_URL"] = args.s3_url
    environ["GPF_S3_KEY"] = args.s3_key
    environ["GPF_S3_SECRETKEY"] = args.s3_secret_key
    environ["GPF_S3_REGION"] = args.s3_region

    # -- RUN LOGIC --

    # check livraison
    logger.user_info("Vérification de la structure de la livraison")
    if not check_livraison_structure(
        work_dir_path=args.work_dir_path,
        in_json_file_name=args.input_configuration_file_name,
        upload_dir_required=False,
    ):
        fail_and_exit_with_message(
            args.work_dir_path,
            "La livraison ne respecte pas la structure attendue. "
            f"Lire le logs du job pour plus d'informations ({args.work_dir_path})",
        )

    # open configuration file
    try:
        parameters: GpfOrchestratorParameters = GpfOrchestratorParameters.from_json(
            Path(args.work_dir_path, args.input_configuration_file_name)
        )
    except Exception as error:
        fail_and_exit_with_message(
            args.work_dir_path,
            "Lecture du fichier de configuration "
            f"({args.work_dir_path}/{args.input_configuration_file_name} en erreur. "
            f"Trace: {error}",
        )

    # Download files in upload folder
    paths: dict = {}
    failures: list[str] = []
    try:
        logger.user_info("Récupèration des fichiers de la livraison")
        upload_dir_path: Path = args.work_dir_path.joinpath(args.upload_dir_name)
        upload_dir_path.mkdir(exist_ok=True)
        paths, failures = parameters.retrieve_input_files(dest=upload_dir_path)
    except Exception as error:
        fail_and_exit_with_message(
            args.work_dir_path,
            f"Récupération des fichiers de la livraison impossible. Trace: {error}",
        )

    if len(failures) != 0:
        fail_and_exit_with_message(
            args.work_dir_path,
            f"Récupération des fichiers de la livraison impossible. Trace: {failures}",
        )

    # Run
    try:
        run_result = run(
            upload_dir_paths=paths,
            parameters=parameters,
            processing_type=args.processing_type,
        )
        parameters.set_pipeline_status(__executable_name__, run_result)

        if run_result == Status.SUCCESS:
            output_db = parameters.output_database
            logger.info(
                f"Calcul des informations liées au schéma {output_db.schema_name} "
                f"de la base de données {output_db.database_name}"
            )
            db_inspector = PgDatabaseInspector(output_db)

            process_extent = get_process_extent_from_parameters(parameters)

            parameters.output_stored_data = db_inspector.update_stored_data(
                parameters.output_stored_data,
                process_extent,
                parameters.input_uploads[0].srs,
            )

    except Exception as error:
        logger.error(
            f"TECHNICAL ERROR - L'exécution de {__title__} (version {__version__}) a "
            f"échoué à cause d'une erreur inattendue. Trace : {error}"
        )
        parameters.set_pipeline_status(__executable_name__, Status.TECHNICAL_ERROR)

    # create output file
    parameters.create_output_file(args.work_dir_path)


# -- Stand alone execution
if __name__ == "__main__":
    main()  # required by unittest
