import logging
from pathlib import Path

import psycopg as pg
from gpf_entrepot_toolbelt.orchestrator.models import PgDatabase

# -- GLOBALS

# logs
logger = logging.getLogger(__name__)


class DatabaseUtils:
    """Helpers interface with Postgres."""

    def __init__(self, db: PgDatabase):
        """Instanciation.

        Args:
            db (PgDatabase): Postgres database object
        """
        self.pg_database = db
        self.conn_string = db.pg_connection_string
        self.active_schema = db.schema_name

    def execute(self, sql: str) -> pg.Cursor:
        """Executes the passed SQL query.

        Args:
            sql (str): SQL query
        """
        with pg.connect(self.conn_string) as con:
            with con.cursor() as cur:
                result = cur.execute(query=sql)

        return result

    def execute_file(self, sql_file: Path, search_path: str | None = None):
        """Executes queries stored in SQL file (.sql). Use carrefully.

        Args:
            sql_file (Path): path to the SQL file to load from
            search_path (str | None, optional): optional schema name to add to the
                search path, in addition to the public schema. Defaults to None.
        """
        with pg.connect(self.conn_string) as con:
            with con.cursor() as cur:
                if search_path:
                    cur.execute(f"SET search_path = {search_path}, public")
                cur.execute(open(sql_file).read())

    def fetch_first_element(self, sql: str) -> str | None:
        """Fetches only the firt row of the SQL query.

        Args:
            sql (str): SQL query

        Returns:
            str | None: query first result
        """
        res = None
        with pg.connect(self.conn_string) as con:
            with con.cursor() as cur:
                cur.execute(sql)
                res = cur.fetchone()[0]

        return res

    def create_schema(self, schema_name: str) -> pg.Cursor:
        """Creates a schema in the database.

        Args:
            schema_name (str): schema name

        Returns:
            _type_: _description_
        """
        return self.execute(f"CREATE SCHEMA {schema_name}")

    def drop_schema(self, schema_name: str, enable_cascade: bool = False) -> pg.Cursor:
        """Drop a schema, in cascade or not, from the database.

        Args:
            schema_name (str): name of the schema to drop
            enable_cascade (bool, optional): enable DROP in cascade. Defaults to False.
        """
        enable_cascade = "CASCADE" if enable_cascade else ""
        return self.execute(f"DROP SCHEMA IF EXISTS {schema_name} {enable_cascade}")

    def duplicate_table_structure(
        self,
        src_schema_name: str,
        src_table_name: str,
        dst_schema_name: str,
        dst_table_name: str,
    ) -> pg.Cursor:
        """Create a new table (destination) from the structure of another one (source).

        Args:
            src_schema_name (str): source table's schema
            src_table_name (str): source table's name
            dst_schema_name (str): destination table's schema
            dst_table_name (str): destination table's name
        """
        sql = f"""
        CREATE TABLE "{dst_schema_name}"."{dst_table_name}"(
            LIKE "{src_schema_name}"."{src_table_name}"
            INCLUDING all
        )
        """
        return self.execute(sql)

    def is_schema_exists(self, schema_name: str) -> bool:
        """Returns True if the given schema exists. Else False.

        Args:
            schema_name (str): name of the schema to check

        Returns:
            bool: True if the schema exists.
        """
        sql = f"""
        SELECT EXISTS (
        SELECT FROM pg_tables
        WHERE  schemaname = '{schema_name}'
        );
        """
        return self.fetch_first_element(sql)

    def is_table_exists(self, schema_name: str, table_name: str) -> bool:
        """Returns True if the given table exists. Else False.

        Args:
            schema_name (str): table's schema name
            table_name (str): table's name

        Returns:
            bool: True if the table exists.
        """
        sql = f"""
        SELECT EXISTS (
        SELECT FROM pg_tables
        WHERE  schemaname = '{schema_name}'
        AND    tablename  = '{table_name}'
        );
        """
        return self.fetch_first_element(sql)

    def copy_values_data(
        self,
        src_schema_name: str,
        src_table_name: str,
        dst_schema_name: str,
        dst_table_name: str,
        columns_name: list[str],
    ) -> pg.Cursor:
        """Copy data from source to destination table with columns name possibly using
            where filter.

        Args:
            src_schema_name (str): source table's schema
            src_table_name (str): source table's name
            dst_schema_name (str): destination table's schema
            dst_table_name (str): destination table's name
            columns_name (list[str]): columns name to filter on
        """
        sql = f"""
        INSERT INTO {dst_schema_name}.{dst_table_name} ("{'","'.join(columns_name)}")
        SELECT "{'","'.join(columns_name)}" FROM {src_schema_name}.{src_table_name}
        """
        sql = self.update_query_to_remove_index(sql, dst_schema_name, dst_table_name)
        logger.debug(f"{sql=}")
        return self.execute(sql)

    def active_schema(self) -> str | None:
        """Returns the active schema if present else None

        Returns:
            str | None: active schema name if present
        """
        return self.active_schema

    def update_query_to_remove_index(
        self, sql: str, schema_name: str, table_name: str
    ) -> str:
        """Update query to remove indexes of schema_name.table_name at the beginning of the transaction
        and recreate indexes at the end of the transaction.
        Only indexes that do not have a dependency constraint are removed

        This function is useful for the time of inserting a huge
        amount of data.

        Args:
            sql (str): query to update
            schema_name (str): table schema
            table_name (str): table name

        Returns:
            str | None: updated query
        """
        sql_get_index = f"""
        SELECT indexname, indexdef  FROM pg_indexes
        WHERE tablename = '{table_name}' AND schemaname = '{schema_name}';
        """
        sql_drop_index = ""
        sql_create_index = ""
        with pg.connect(self.conn_string) as con:
            with con.cursor() as cur:
                logger.debug(f"{sql_get_index=}")
                cur.execute(sql_get_index)
                res = cur.fetchall()
                for index in res:
                    sql_get_constraint = f"""
                    SELECT oid FROM pg_constraint
                    WHERE conname='{index[0]}'
                    AND conrelid=(SELECT '{schema_name}.{table_name}'::regclass::oid);
                    """
                    cur.execute(sql_get_constraint)
                    constraints = cur.fetchall()
                    if not constraints:
                        sql_drop_index += f"DROP INDEX {schema_name}.{index[0]}; "
                        sql_create_index += f"{index[1]}; "
        return f"LOCK TABLE {schema_name}.{table_name} IN ACCESS EXCLUSIVE MODE; {sql_drop_index} {sql.rstrip(';')}; {sql_create_index}"
