#! python3  # noqa E265

"""
    Usage from the repo root folder:

    .. code-block:: bash
        pytest
"""
import json
import os
import subprocess
from os import environ
from pathlib import Path
from unittest import TestCase

# standard
import boto3
import psycopg

# 3rd party
import pytest
from moto import mock_s3

# project
from gpf_vector_to_db import __about__, cli

# ############################################################################
# ########## Globals #############
# ################################
HOST = os.environ.get("POSTGRES_HOST", "localhost")
PORT = int(os.environ.get("PORT", 5555))
DBNAME = os.environ.get("POSTGRES_DB", "ign")

USER = os.environ.get("POSTGRES_USER", "ign")
PASS = os.environ.get("POSTGRES_PASSWORD", "ign_password")

# Schemas are defined in input configuration .json files
OUTPUT_SCHEMA = "schema_output"
BUCKET_NAME = "telechargement-dev"

cur_dir = Path(__file__).parent.absolute()

TestCase.maxDiff = None


def replace_template_parameter_json(file_path: Path, output_file_path: Path):
    """Update .json file to replace template parameters. Supported parameters:
    - %PORT%
    - %HOST%

    Parameters
    ----------
    file_path (Path) database .json file path
    """
    with open(file_path) as f:
        content = f.read().replace("%PORT%", str(PORT)).replace("%HOST%", HOST)

    output_file_path.parent.mkdir(exist_ok=True, parents=True)
    with open(output_file_path, mode="w") as f:
        f.write(content)


def read_json_file(file: Path) -> dict:
    """Retourne un fichier json sous forme de dictionnaire

    Returns:
        dict: dictionnaire json
    """
    with open(file) as json_file:
        data = json.load(json_file)
        return data


@mock_s3
def s3_upload_stored_data(_id: str):
    """_summary_

    Args:
        _id (str): _description_
    """
    s3 = boto3.client("s3")
    s3.create_bucket(Bucket=BUCKET_NAME)
    input_data_path = f"tests/fixtures/data/{_id}"
    for root, dirs, files in os.walk(input_data_path):
        for file in files:
            file_path = os.path.join(root, file)
            key = "uploads/" + str(file_path.removeprefix("tests/fixtures/data/"))
            s3.upload_file(file_path, BUCKET_NAME, key)


def drop_output_schema() -> None:
    """_summary_"""
    with psycopg.connect(
        host=HOST, dbname=DBNAME, user=USER, password=PASS, port=PORT
    ) as con:
        con.cursor().execute(f"DROP SCHEMA IF EXISTS {OUTPUT_SCHEMA} CASCADE")


def create_output_schema() -> None:
    """_summary_"""
    with psycopg.connect(
        host=HOST, dbname=DBNAME, user=USER, password=PASS, port=PORT
    ) as con:
        con.cursor().execute(f"CREATE SCHEMA {OUTPUT_SCHEMA}")


def init_test_case(
    execution_path: Path, upload_name: str, param_file: str, drop_schema: bool = True
) -> None:
    """_summary_

    Args:
        execution_path (Path): _description_
        upload_name (str): _description_
        param_file (str): _description_
        drop_schema (bool, optional): _description_. Defaults to True.
    """
    # Insert stored data for upload
    s3_upload_stored_data(upload_name)

    input_param_dir = cur_dir / "fixtures"
    replace_template_parameter_json(
        input_param_dir / param_file,
        execution_path / param_file,
    )
    if drop_schema:
        drop_output_schema()


def init_and_run_processing(
    execution_path: Path,
    upload_name: str,
    param_file: str,
    drop_schema: bool = True,
    extra_args: list = [],
) -> None:
    """_summary_

    Args:
        execution_path (Path): _description_
        upload_name (str): _description_
        param_file (str): _description_
        drop_schema (bool, optional): _description_. Defaults to True.
        extra_args (list, optional): _description_. Defaults to [].
    """
    init_test_case(execution_path, upload_name, param_file, drop_schema)

    environ["GPF_WORK_DIR"] = str(execution_path)
    environ["GPF_INPUT_CONFIGURATION_FILENAME"] = param_file
    environ["GPF_POSTGRESQL_USER"] = "ign"
    environ["GPF_POSTGRESQL_PASS"] = "ign_password"

    cli.main(extra_args + ["--s3-url", ""])


# ############################################################################
# ########## Classes #############
# ################################
def check_output_stored_data_relation_and_extent(
    output_stored_data: dict,
    expected_stored_data_extent: dict | None,
    expected_stored_data_relations: list[dict],
) -> None:
    """_summary_

    Args:
        output_stored_data (dict): _description_
        expected_stored_data_extent (dict | None): _description_
        expected_stored_data_relations (list[dict]): _description_
    """
    TestCase().assertCountEqual(
        output_stored_data["type_infos"]["relations"], expected_stored_data_relations
    )

    if expected_stored_data_extent is None:
        assert (
            "extent" not in output_stored_data or output_stored_data["extent"] is None
        )
    else:
        assert output_stored_data["extent"] == expected_stored_data_extent


@mock_s3
def test_cli_run_normal(tmp_path):
    """Test run normal test."""
    init_and_run_processing(tmp_path, "normal", "parameters_normal.json")

    # Check some expected outputs
    result = read_json_file(Path(tmp_path / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "SUCCESS"

    output_stored_data = result["output"]["stored_data"]
    expected_stored_data_relations = [
        {
            "name": "test_point",
            "type": "TABLE",
            "attributes": {
                "geometry": "geometry(Point,4326)",
                "insee": "character varying",
                "nom": "character varying",
                "fid": "integer",
                "prénom": "character varying",
            },
            "primary_key": ["fid"],
        },
        {
            "name": "test_line",
            "type": "TABLE",
            "attributes": {
                "geometry": "geometry(LineString,4326)",
                "fid": "integer",
            },
            "primary_key": ["fid"],
        },
        {
            "name": "test_polygon",
            "type": "TABLE",
            "attributes": {
                "geometry": "geometry(Polygon,4326)",
                "fid": "integer",
                "rvb": "character varying",
            },
            "primary_key": ["fid"],
        },
        {
            "name": "test_ajout",
            "type": "TABLE",
            "attributes": {
                "fid": "double precision",
                "insee": "character varying(254)",
                "nom": "character varying(254)",
                "ogc_fid": "integer",
                "prénom": "character varying(254)",
                "wkb_geometry": "geometry(Point,4326)",
            },
            "primary_key": ["ogc_fid"],
        },
        {
            "name": "test_xy",
            "type": "TABLE",
            "attributes": {
                "insee": "character varying",
                "nom": "character varying",
                "fid": "integer",
                "prénom": "character varying",
                "x": "character varying",
                "y": "character varying",
            },
            "primary_key": ["fid"],
        },
        {
            "name": "test_base",
            "type": "TABLE",
            "attributes": {
                "fid": "double precision",
                "insee": "character varying(254)",
                "nom": "character varying(254)",
                "ogc_fid": "integer",
                "prénom": "character varying(254)",
                "wkb_geometry": "geometry(Point,4326)",
            },
            "primary_key": ["ogc_fid"],
        },
        {
            "name": "test_base_xy",
            "type": "TABLE",
            "attributes": {
                "fid": "character varying",
                "insee": "character varying",
                "nom": "character varying",
                "ogc_fid": "integer",
                "prénom": "character varying",
                "wkb_geometry": "geometry(Point,4326)",
            },
            "primary_key": ["ogc_fid"],
        },
    ]

    expected_stored_data_extent = {
        "type": "Feature",
        "geometry": {
            "coordinates": [
                [
                    [
                        [-1.40625, 44.598828125],
                        [-1.23046875, 44.598828125],
                        [-1.23046875, 44.423242188],
                        [-1.40625, 44.423242188],
                        [-1.40625, 44.598828125],
                    ]
                ],
                [
                    [
                        [1.58203125, 45.301171875],
                        [1.58203125, 45.476757812],
                        [1.7578125, 45.476757812],
                        [1.7578125, 45.65234375],
                        [1.7578125, 45.827929688],
                        [1.58203125, 45.827929688],
                        [1.58203125, 45.65234375],
                        [1.40625, 45.65234375],
                        [1.23046875, 45.65234375],
                        [1.0546875, 45.65234375],
                        [1.0546875, 45.827929688],
                        [1.23046875, 45.827929688],
                        [1.40625, 45.827929688],
                        [1.40625, 46.003515625],
                        [1.23046875, 46.003515625],
                        [1.0546875, 46.003515625],
                        [1.0546875, 46.179101563],
                        [1.23046875, 46.179101563],
                        [1.40625, 46.179101563],
                        [1.40625, 46.3546875],
                        [1.58203125, 46.3546875],
                        [1.7578125, 46.3546875],
                        [1.7578125, 46.530273438],
                        [1.93359375, 46.530273438],
                        [2.109375, 46.530273438],
                        [2.28515625, 46.530273438],
                        [2.4609375, 46.530273438],
                        [2.63671875, 46.530273438],
                        [2.63671875, 46.3546875],
                        [2.8125, 46.3546875],
                        [2.8125, 46.530273438],
                        [2.8125, 46.705859375],
                        [2.8125, 46.881445313],
                        [2.8125, 47.05703125],
                        [2.8125, 47.232617188],
                        [2.8125, 47.408203125],
                        [2.8125, 47.583789062],
                        [2.8125, 47.759375],
                        [2.98828125, 47.759375],
                        [2.98828125, 47.934960938],
                        [2.98828125, 48.110546875],
                        [2.8125, 48.110546875],
                        [2.8125, 48.286132812],
                        [2.8125, 48.46171875],
                        [2.63671875, 48.46171875],
                        [2.4609375, 48.46171875],
                        [2.4609375, 48.286132812],
                        [2.28515625, 48.286132812],
                        [2.28515625, 48.110546875],
                        [2.28515625, 47.934960938],
                        [2.109375, 47.934960938],
                        [2.109375, 47.759375],
                        [2.109375, 47.583789062],
                        [2.109375, 47.408203125],
                        [2.109375, 47.232617188],
                        [1.93359375, 47.232617188],
                        [1.93359375, 47.05703125],
                        [1.7578125, 47.05703125],
                        [1.7578125, 46.881445313],
                        [1.7578125, 46.705859375],
                        [1.58203125, 46.705859375],
                        [1.58203125, 46.530273438],
                        [1.40625, 46.530273438],
                        [1.23046875, 46.530273438],
                        [1.23046875, 46.3546875],
                        [1.0546875, 46.3546875],
                        [0.87890625, 46.3546875],
                        [0.703125, 46.3546875],
                        [0.703125, 46.530273438],
                        [0.52734375, 46.530273438],
                        [0.52734375, 46.705859375],
                        [0.52734375, 46.881445313],
                        [0.52734375, 47.05703125],
                        [0.52734375, 47.232617188],
                        [0.52734375, 47.408203125],
                        [0.52734375, 47.583789062],
                        [0.52734375, 47.759375],
                        [0.52734375, 47.934960938],
                        [0.52734375, 48.110546875],
                        [0.703125, 48.110546875],
                        [0.703125, 48.286132812],
                        [0.703125, 48.46171875],
                        [0.703125, 48.637304688],
                        [0.87890625, 48.637304688],
                        [0.87890625, 48.812890625],
                        [1.0546875, 48.812890625],
                        [1.0546875, 48.988476563],
                        [1.0546875, 49.1640625],
                        [1.23046875, 49.1640625],
                        [1.23046875, 49.339648438],
                        [1.40625, 49.339648438],
                        [1.58203125, 49.339648438],
                        [1.58203125, 49.515234375],
                        [1.7578125, 49.515234375],
                        [1.93359375, 49.515234375],
                        [1.93359375, 49.690820313],
                        [2.109375, 49.690820313],
                        [2.28515625, 49.690820313],
                        [2.4609375, 49.690820313],
                        [2.63671875, 49.690820313],
                        [2.8125, 49.690820313],
                        [2.98828125, 49.690820313],
                        [2.98828125, 49.515234375],
                        [2.98828125, 49.339648438],
                        [3.1640625, 49.339648438],
                        [3.1640625, 49.1640625],
                        [3.1640625, 48.988476563],
                        [3.33984375, 48.988476563],
                        [3.515625, 48.988476563],
                        [3.515625, 49.1640625],
                        [3.515625, 49.339648438],
                        [3.69140625, 49.339648438],
                        [3.69140625, 49.515234375],
                        [3.8671875, 49.515234375],
                        [3.8671875, 49.690820313],
                        [4.04296875, 49.690820313],
                        [4.21875, 49.690820313],
                        [4.39453125, 49.690820313],
                        [4.5703125, 49.690820313],
                        [4.74609375, 49.690820313],
                        [4.921875, 49.690820313],
                        [5.09765625, 49.690820313],
                        [5.2734375, 49.690820313],
                        [5.44921875, 49.690820313],
                        [5.44921875, 49.515234375],
                        [5.625, 49.515234375],
                        [5.80078125, 49.515234375],
                        [5.80078125, 49.339648438],
                        [5.9765625, 49.339648438],
                        [5.9765625, 49.1640625],
                        [6.15234375, 49.1640625],
                        [6.15234375, 48.988476563],
                        [6.328125, 48.988476563],
                        [6.328125, 48.812890625],
                        [6.50390625, 48.812890625],
                        [6.50390625, 48.637304688],
                        [6.50390625, 48.46171875],
                        [6.6796875, 48.46171875],
                        [6.6796875, 48.286132812],
                        [6.6796875, 48.110546875],
                        [6.85546875, 48.110546875],
                        [6.85546875, 47.934960938],
                        [6.85546875, 47.759375],
                        [6.85546875, 47.583789062],
                        [6.85546875, 47.408203125],
                        [6.85546875, 47.232617188],
                        [6.85546875, 47.05703125],
                        [6.85546875, 46.881445313],
                        [6.6796875, 46.881445313],
                        [6.50390625, 46.881445313],
                        [6.328125, 46.881445313],
                        [6.15234375, 46.881445313],
                        [5.9765625, 46.881445313],
                        [5.9765625, 46.705859375],
                        [6.15234375, 46.705859375],
                        [6.328125, 46.705859375],
                        [6.50390625, 46.705859375],
                        [6.50390625, 46.530273438],
                        [6.328125, 46.530273438],
                        [6.15234375, 46.530273438],
                        [5.9765625, 46.530273438],
                        [5.80078125, 46.530273438],
                        [5.80078125, 46.3546875],
                        [5.80078125, 46.179101563],
                        [5.9765625, 46.179101563],
                        [6.15234375, 46.179101563],
                        [6.328125, 46.179101563],
                        [6.50390625, 46.179101563],
                        [6.50390625, 46.003515625],
                        [6.328125, 46.003515625],
                        [6.15234375, 46.003515625],
                        [5.9765625, 46.003515625],
                        [5.80078125, 46.003515625],
                        [5.80078125, 45.827929688],
                        [5.625, 45.827929688],
                        [5.625, 45.65234375],
                        [5.44921875, 45.65234375],
                        [5.2734375, 45.65234375],
                        [5.09765625, 45.65234375],
                        [5.09765625, 45.476757812],
                        [4.921875, 45.476757812],
                        [4.74609375, 45.476757812],
                        [4.74609375, 45.301171875],
                        [4.5703125, 45.301171875],
                        [4.39453125, 45.301171875],
                        [4.39453125, 45.125585938],
                        [4.5703125, 45.125585938],
                        [4.74609375, 45.125585938],
                        [4.74609375, 44.95],
                        [4.74609375, 44.774414062],
                        [4.74609375, 44.598828125],
                        [4.74609375, 44.423242188],
                        [4.74609375, 44.24765625],
                        [4.5703125, 44.24765625],
                        [4.5703125, 44.072070312],
                        [4.5703125, 43.896484375],
                        [4.5703125, 43.720898438],
                        [4.39453125, 43.720898438],
                        [4.21875, 43.720898438],
                        [4.04296875, 43.720898438],
                        [4.04296875, 43.896484375],
                        [3.8671875, 43.896484375],
                        [3.69140625, 43.896484375],
                        [3.69140625, 43.720898438],
                        [3.515625, 43.720898438],
                        [3.33984375, 43.720898438],
                        [3.1640625, 43.720898438],
                        [3.1640625, 43.896484375],
                        [3.1640625, 44.072070312],
                        [3.1640625, 44.24765625],
                        [2.98828125, 44.24765625],
                        [2.98828125, 44.423242188],
                        [2.98828125, 44.598828125],
                        [2.98828125, 44.774414062],
                        [2.98828125, 44.95],
                        [2.8125, 44.95],
                        [2.8125, 45.125585938],
                        [2.63671875, 45.125585938],
                        [2.4609375, 45.125585938],
                        [2.28515625, 45.125585938],
                        [2.109375, 45.125585938],
                        [2.109375, 45.301171875],
                        [1.93359375, 45.301171875],
                        [1.7578125, 45.301171875],
                        [1.7578125, 45.125585938],
                        [1.58203125, 45.125585938],
                        [1.40625, 45.125585938],
                        [1.23046875, 45.125585938],
                        [1.23046875, 45.301171875],
                        [1.40625, 45.301171875],
                        [1.58203125, 45.301171875],
                    ],
                    [
                        [4.921875, 48.286132812],
                        [4.74609375, 48.286132812],
                        [4.74609375, 48.46171875],
                        [4.5703125, 48.46171875],
                        [4.39453125, 48.46171875],
                        [4.39453125, 48.286132812],
                        [4.21875, 48.286132812],
                        [4.21875, 48.110546875],
                        [4.39453125, 48.110546875],
                        [4.39453125, 47.934960938],
                        [4.39453125, 47.759375],
                        [4.39453125, 47.583789062],
                        [4.39453125, 47.408203125],
                        [4.5703125, 47.408203125],
                        [4.5703125, 47.232617188],
                        [4.5703125, 47.05703125],
                        [4.5703125, 46.881445313],
                        [4.39453125, 46.881445313],
                        [4.39453125, 46.705859375],
                        [4.5703125, 46.705859375],
                        [4.74609375, 46.705859375],
                        [4.74609375, 46.881445313],
                        [4.921875, 46.881445313],
                        [4.921875, 47.05703125],
                        [5.09765625, 47.05703125],
                        [5.09765625, 46.881445313],
                        [5.2734375, 46.881445313],
                        [5.44921875, 46.881445313],
                        [5.625, 46.881445313],
                        [5.80078125, 46.881445313],
                        [5.80078125, 47.05703125],
                        [5.625, 47.05703125],
                        [5.625, 47.232617188],
                        [5.44921875, 47.232617188],
                        [5.44921875, 47.408203125],
                        [5.44921875, 47.583789062],
                        [5.2734375, 47.583789062],
                        [5.2734375, 47.759375],
                        [5.09765625, 47.759375],
                        [5.09765625, 47.934960938],
                        [5.09765625, 48.110546875],
                        [4.921875, 48.110546875],
                        [4.921875, 48.286132812],
                    ],
                ],
                [
                    [
                        [0.3515625, 48.110546875],
                        [0.3515625, 47.934960938],
                        [0.17578125, 47.934960938],
                        [0.17578125, 48.110546875],
                        [0.3515625, 48.110546875],
                    ]
                ],
                [
                    [
                        [1.40625, 52.851367188],
                        [1.40625, 52.67578125],
                        [1.23046875, 52.67578125],
                        [1.23046875, 52.851367188],
                        [1.40625, 52.851367188],
                    ]
                ],
                [
                    [
                        [2.4609375, 51.9734375],
                        [2.4609375, 51.797851563],
                        [2.28515625, 51.797851563],
                        [2.28515625, 51.9734375],
                        [2.4609375, 51.9734375],
                    ]
                ],
                [
                    [
                        [5.44921875, 43.369726563],
                        [5.44921875, 43.194140625],
                        [5.2734375, 43.194140625],
                        [5.2734375, 43.369726563],
                        [5.44921875, 43.369726563],
                    ]
                ],
                [
                    [
                        [6.6796875, 46.003515625],
                        [6.6796875, 45.827929688],
                        [6.50390625, 45.827929688],
                        [6.50390625, 46.003515625],
                        [6.6796875, 46.003515625],
                    ]
                ],
            ],
            "type": "MultiPolygon",
        },
    }

    check_output_stored_data_relation_and_extent(
        output_stored_data=output_stored_data,
        expected_stored_data_extent=expected_stored_data_extent,
        expected_stored_data_relations=expected_stored_data_relations,
    )
    drop_output_schema()


@mock_s3
def test_cli_run_lambert93(tmp_path):
    """Test run with non WGS84 test."""
    init_and_run_processing(tmp_path, "lambert93", "parameters_l93.json")

    # Check some expected outputs
    result = read_json_file(Path(tmp_path / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "SUCCESS"

    output_stored_data = result["output"]["stored_data"]
    expected_stored_data_relations = [
        {
            "name": "test_point",
            "type": "TABLE",
            "attributes": {
                "geom": "geometry(Point,2154)",
                "insee": "character varying",
                "nom": "character varying",
                "fid": "integer",
                "prénom": "character varying",
            },
            "primary_key": ["fid"],
        },
    ]

    expected_stored_data_extent = {
        "type": "Feature",
        "geometry": {
            "coordinates": [
                [
                    [
                        [5.423769531, 43.300112305],
                        [5.423769531, 43.295029297],
                        [5.418828125, 43.295029297],
                        [5.418828125, 43.300112305],
                        [5.423769531, 43.300112305],
                    ]
                ],
                [
                    [
                        [-1.247128906, 44.44887207],
                        [-1.247128906, 44.443789062],
                        [-1.252070312, 44.443789062],
                        [-1.252070312, 44.44887207],
                        [-1.247128906, 44.44887207],
                    ]
                ],
                [
                    [
                        [6.644296875, 45.938193359],
                        [6.644296875, 45.933110352],
                        [6.639355469, 45.933110352],
                        [6.639355469, 45.938193359],
                        [6.644296875, 45.938193359],
                    ]
                ],
                [
                    [
                        [0.185878906, 47.996811523],
                        [0.185878906, 47.991728516],
                        [0.1809375, 47.991728516],
                        [0.1809375, 47.996811523],
                        [0.185878906, 47.996811523],
                    ]
                ],
            ],
            "type": "MultiPolygon",
        },
    }

    check_output_stored_data_relation_and_extent(
        output_stored_data=output_stored_data,
        expected_stored_data_extent=expected_stored_data_extent,
        expected_stored_data_relations=expected_stored_data_relations,
    )
    drop_output_schema()


@mock_s3
def test_cli_run_multi(tmp_path):
    """Test run with multi-geom test."""
    init_and_run_processing(tmp_path, "multigeom", "parameters_multi.json")

    # Check some expected outputs
    result = read_json_file(Path(tmp_path / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "SUCCESS"

    output_stored_data = result["output"]["stored_data"]
    expected_stored_data_relations = [
        {
            "name": "multiopoly",
            "type": "TABLE",
            "attributes": {
                "geometry": "geometry(MultiPolygon,2154)",
                "fid": "integer",
            },
            "primary_key": ["fid"],
        },
    ]

    expected_stored_data_extent = {
        "geometry": {
            "coordinates": [
                [
                    [
                        [5.35953125, 46.151679688],
                        [5.35953125, 46.172011719],
                        [5.35953125, 46.19234375],
                        [5.35953125, 46.212675781],
                        [5.35953125, 46.233007813],
                        [5.35953125, 46.253339844],
                        [5.35953125, 46.273671875],
                        [5.35953125, 46.294003906],
                        [5.35953125, 46.314335938],
                        [5.35953125, 46.334667969],
                        [5.3990625, 46.334667969],
                        [5.3990625, 46.355],
                        [5.3990625, 46.375332031],
                        [5.3990625, 46.395664062],
                        [5.3990625, 46.415996094],
                        [5.3990625, 46.436328125],
                        [5.3990625, 46.456660156],
                        [5.43859375, 46.456660156],
                        [5.478125, 46.456660156],
                        [5.51765625, 46.456660156],
                        [5.5571875, 46.456660156],
                        [5.59671875, 46.456660156],
                        [5.63625, 46.456660156],
                        [5.63625, 46.436328125],
                        [5.67578125, 46.436328125],
                        [5.7153125, 46.436328125],
                        [5.75484375, 46.436328125],
                        [5.794375, 46.436328125],
                        [5.83390625, 46.436328125],
                        [5.8734375, 46.436328125],
                        [5.91296875, 46.436328125],
                        [5.91296875, 46.415996094],
                        [5.91296875, 46.395664062],
                        [5.91296875, 46.375332031],
                        [5.91296875, 46.355],
                        [5.91296875, 46.334667969],
                        [5.91296875, 46.314335938],
                        [5.91296875, 46.294003906],
                        [5.91296875, 46.273671875],
                        [5.8734375, 46.273671875],
                        [5.83390625, 46.273671875],
                        [5.83390625, 46.253339844],
                        [5.794375, 46.253339844],
                        [5.75484375, 46.253339844],
                        [5.75484375, 46.233007813],
                        [5.7153125, 46.233007813],
                        [5.67578125, 46.233007813],
                        [5.67578125, 46.212675781],
                        [5.63625, 46.212675781],
                        [5.63625, 46.19234375],
                        [5.59671875, 46.19234375],
                        [5.5571875, 46.19234375],
                        [5.5571875, 46.172011719],
                        [5.51765625, 46.172011719],
                        [5.478125, 46.172011719],
                        [5.478125, 46.151679688],
                        [5.43859375, 46.151679688],
                        [5.3990625, 46.151679688],
                        [5.3990625, 46.131347656],
                        [5.35953125, 46.131347656],
                        [5.35953125, 46.151679688],
                    ],
                    [
                        [5.51765625, 46.334667969],
                        [5.51765625, 46.314335938],
                        [5.51765625, 46.294003906],
                        [5.5571875, 46.294003906],
                        [5.59671875, 46.294003906],
                        [5.59671875, 46.314335938],
                        [5.63625, 46.314335938],
                        [5.63625, 46.334667969],
                        [5.63625, 46.355],
                        [5.59671875, 46.355],
                        [5.5571875, 46.355],
                        [5.5571875, 46.334667969],
                        [5.51765625, 46.334667969],
                    ],
                ],
                [
                    [
                        [5.7153125, 45.806035156],
                        [5.7153125, 45.826367188],
                        [5.7153125, 45.846699219],
                        [5.7153125, 45.86703125],
                        [5.75484375, 45.86703125],
                        [5.75484375, 45.887363281],
                        [5.75484375, 45.907695312],
                        [5.794375, 45.907695312],
                        [5.794375, 45.928027344],
                        [5.794375, 45.948359375],
                        [5.83390625, 45.948359375],
                        [5.83390625, 45.968691406],
                        [5.83390625, 45.989023437],
                        [5.8734375, 45.989023437],
                        [5.8734375, 46.009355469],
                        [5.8734375, 46.0296875],
                        [5.91296875, 46.0296875],
                        [5.91296875, 46.050019531],
                        [5.91296875, 46.070351563],
                        [5.9525, 46.070351563],
                        [5.99203125, 46.070351563],
                        [6.0315625, 46.070351563],
                        [6.0315625, 46.050019531],
                        [6.07109375, 46.050019531],
                        [6.110625, 46.050019531],
                        [6.110625, 46.0296875],
                        [6.15015625, 46.0296875],
                        [6.1896875, 46.0296875],
                        [6.1896875, 46.009355469],
                        [6.22921875, 46.009355469],
                        [6.26875, 46.009355469],
                        [6.26875, 45.989023437],
                        [6.30828125, 45.989023437],
                        [6.30828125, 45.968691406],
                        [6.30828125, 45.948359375],
                        [6.3478125, 45.948359375],
                        [6.3478125, 45.928027344],
                        [6.3478125, 45.907695312],
                        [6.3478125, 45.887363281],
                        [6.38734375, 45.887363281],
                        [6.38734375, 45.86703125],
                        [6.38734375, 45.846699219],
                        [6.38734375, 45.826367188],
                        [6.426875, 45.826367188],
                        [6.426875, 45.806035156],
                        [6.426875, 45.785703125],
                        [6.426875, 45.765371094],
                        [6.46640625, 45.765371094],
                        [6.46640625, 45.745039062],
                        [6.46640625, 45.724707031],
                        [6.46640625, 45.704375],
                        [6.5059375, 45.704375],
                        [6.5059375, 45.684042969],
                        [6.5059375, 45.663710938],
                        [6.54546875, 45.663710938],
                        [6.54546875, 45.643378906],
                        [6.54546875, 45.623046875],
                        [6.54546875, 45.602714844],
                        [6.585, 45.602714844],
                        [6.585, 45.582382812],
                        [6.585, 45.562050781],
                        [6.585, 45.54171875],
                        [6.585, 45.521386719],
                        [6.54546875, 45.521386719],
                        [6.54546875, 45.54171875],
                        [6.5059375, 45.54171875],
                        [6.46640625, 45.54171875],
                        [6.46640625, 45.562050781],
                        [6.426875, 45.562050781],
                        [6.426875, 45.582382812],
                        [6.38734375, 45.582382812],
                        [6.3478125, 45.582382812],
                        [6.3478125, 45.602714844],
                        [6.30828125, 45.602714844],
                        [6.30828125, 45.623046875],
                        [6.26875, 45.623046875],
                        [6.22921875, 45.623046875],
                        [6.22921875, 45.643378906],
                        [6.1896875, 45.643378906],
                        [6.1896875, 45.663710938],
                        [6.15015625, 45.663710938],
                        [6.110625, 45.663710938],
                        [6.110625, 45.684042969],
                        [6.07109375, 45.684042969],
                        [6.07109375, 45.704375],
                        [6.0315625, 45.704375],
                        [5.99203125, 45.704375],
                        [5.99203125, 45.724707031],
                        [5.9525, 45.724707031],
                        [5.9525, 45.745039062],
                        [5.91296875, 45.745039062],
                        [5.8734375, 45.745039062],
                        [5.8734375, 45.765371094],
                        [5.83390625, 45.765371094],
                        [5.83390625, 45.785703125],
                        [5.794375, 45.785703125],
                        [5.75484375, 45.785703125],
                        [5.75484375, 45.806035156],
                        [5.7153125, 45.806035156],
                    ]
                ],
                [
                    [
                        [6.07109375, 46.212675781],
                        [6.07109375, 46.233007813],
                        [6.07109375, 46.253339844],
                        [6.110625, 46.253339844],
                        [6.110625, 46.273671875],
                        [6.15015625, 46.273671875],
                        [6.15015625, 46.294003906],
                        [6.1896875, 46.294003906],
                        [6.1896875, 46.314335938],
                        [6.22921875, 46.314335938],
                        [6.22921875, 46.334667969],
                        [6.26875, 46.334667969],
                        [6.26875, 46.355],
                        [6.30828125, 46.355],
                        [6.3478125, 46.355],
                        [6.38734375, 46.355],
                        [6.38734375, 46.375332031],
                        [6.426875, 46.375332031],
                        [6.46640625, 46.375332031],
                        [6.46640625, 46.395664062],
                        [6.5059375, 46.395664062],
                        [6.54546875, 46.395664062],
                        [6.585, 46.395664062],
                        [6.62453125, 46.395664062],
                        [6.62453125, 46.375332031],
                        [6.6640625, 46.375332031],
                        [6.6640625, 46.355],
                        [6.6640625, 46.334667969],
                        [6.70359375, 46.334667969],
                        [6.70359375, 46.314335938],
                        [6.70359375, 46.294003906],
                        [6.743125, 46.294003906],
                        [6.743125, 46.273671875],
                        [6.743125, 46.253339844],
                        [6.78265625, 46.253339844],
                        [6.78265625, 46.233007813],
                        [6.78265625, 46.212675781],
                        [6.78265625, 46.19234375],
                        [6.78265625, 46.172011719],
                        [6.78265625, 46.151679688],
                        [6.78265625, 46.131347656],
                        [6.78265625, 46.111015625],
                        [6.78265625, 46.090683594],
                        [6.78265625, 46.070351563],
                        [6.743125, 46.070351563],
                        [6.743125, 46.050019531],
                        [6.743125, 46.0296875],
                        [6.743125, 46.009355469],
                        [6.743125, 45.989023437],
                        [6.743125, 45.968691406],
                        [6.743125, 45.948359375],
                        [6.70359375, 45.948359375],
                        [6.70359375, 45.928027344],
                        [6.70359375, 45.907695312],
                        [6.70359375, 45.887363281],
                        [6.70359375, 45.86703125],
                        [6.70359375, 45.846699219],
                        [6.70359375, 45.826367188],
                        [6.6640625, 45.826367188],
                        [6.62453125, 45.826367188],
                        [6.62453125, 45.846699219],
                        [6.585, 45.846699219],
                        [6.585, 45.86703125],
                        [6.54546875, 45.86703125],
                        [6.54546875, 45.887363281],
                        [6.5059375, 45.887363281],
                        [6.5059375, 45.907695312],
                        [6.46640625, 45.907695312],
                        [6.46640625, 45.928027344],
                        [6.426875, 45.928027344],
                        [6.426875, 45.948359375],
                        [6.38734375, 45.948359375],
                        [6.38734375, 45.968691406],
                        [6.3478125, 45.968691406],
                        [6.3478125, 45.989023437],
                        [6.30828125, 45.989023437],
                        [6.30828125, 46.009355469],
                        [6.26875, 46.009355469],
                        [6.26875, 46.0296875],
                        [6.22921875, 46.0296875],
                        [6.22921875, 46.050019531],
                        [6.1896875, 46.050019531],
                        [6.1896875, 46.070351563],
                        [6.15015625, 46.070351563],
                        [6.15015625, 46.090683594],
                        [6.110625, 46.090683594],
                        [6.110625, 46.111015625],
                        [6.07109375, 46.111015625],
                        [6.07109375, 46.131347656],
                        [6.0315625, 46.131347656],
                        [6.0315625, 46.151679688],
                        [5.99203125, 46.151679688],
                        [5.99203125, 46.172011719],
                        [5.99203125, 46.19234375],
                        [6.0315625, 46.19234375],
                        [6.0315625, 46.212675781],
                        [6.07109375, 46.212675781],
                    ]
                ],
                [
                    [
                        [5.99203125, 46.476992188],
                        [5.99203125, 46.497324219],
                        [5.99203125, 46.51765625],
                        [6.0315625, 46.51765625],
                        [6.07109375, 46.51765625],
                        [6.110625, 46.51765625],
                        [6.110625, 46.537988281],
                        [6.15015625, 46.537988281],
                        [6.1896875, 46.537988281],
                        [6.22921875, 46.537988281],
                        [6.22921875, 46.51765625],
                        [6.22921875, 46.497324219],
                        [6.22921875, 46.476992188],
                        [6.22921875, 46.456660156],
                        [6.22921875, 46.436328125],
                        [6.22921875, 46.415996094],
                        [6.22921875, 46.395664062],
                        [6.22921875, 46.375332031],
                        [6.1896875, 46.375332031],
                        [6.15015625, 46.375332031],
                        [6.15015625, 46.355],
                        [6.110625, 46.355],
                        [6.07109375, 46.355],
                        [6.0315625, 46.355],
                        [5.99203125, 46.355],
                        [5.99203125, 46.375332031],
                        [5.99203125, 46.395664062],
                        [5.99203125, 46.415996094],
                        [5.99203125, 46.436328125],
                        [5.99203125, 46.456660156],
                        [5.99203125, 46.476992188],
                    ]
                ],
            ],
            "type": "MultiPolygon",
        },
        "type": "Feature",
    }

    check_output_stored_data_relation_and_extent(
        output_stored_data=output_stored_data,
        expected_stored_data_extent=expected_stored_data_extent,
        expected_stored_data_relations=expected_stored_data_relations,
    )
    drop_output_schema()


@mock_s3
def test_cli_run_srs(tmp_path):
    """Test run with reprojected layer test."""
    init_and_run_processing(tmp_path, "fix_1248", "parameters_fix_1248.json")

    # Check some expected outputs
    result = read_json_file(Path(tmp_path / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "SUCCESS"

    output_stored_data = result["output"]["stored_data"]
    expected_stored_data_relations = [
        {
            "name": "region",
            "type": "TABLE",
            "attributes": {
                "geom": "geometry(MultiPolygon,4326)",
                "id": "character varying(24)",
                "insee_reg": "character varying(2)",
                "nom": "character varying(35)",
                "nom_m": "character varying(35)",
                "fid": "integer",
            },
            "primary_key": ["fid"],
        },
        {
            "name": "epci",
            "type": "TABLE",
            "attributes": {
                "code_siren": "character varying(9)",
                "geom": "geometry(MultiPolygon,4326)",
                "id": "character varying(24)",
                "nature": "character varying(150)",
                "nom": "character varying(230)",
                "fid": "integer",
            },
            "primary_key": ["fid"],
        },
        {
            "name": "departement",
            "type": "TABLE",
            "attributes": {
                "geom": "geometry(MultiPolygon,4326)",
                "id": "character varying(24)",
                "insee_dep": "character varying(3)",
                "insee_reg": "character varying(2)",
                "nom": "character varying(30)",
                "nom_m": "character varying(30)",
                "fid": "integer",
            },
            "primary_key": ["fid"],
        },
        {
            "name": "commune",
            "type": "TABLE",
            "attributes": {
                "geom": "geometry(MultiPolygon,4326)",
                "id": "character varying(24)",
                "insee_arr": "character varying(2)",
                "insee_can": "character varying(5)",
                "insee_com": "character varying(5)",
                "insee_dep": "character varying(3)",
                "insee_reg": "character varying(2)",
                "nom": "character varying(50)",
                "nom_m": "character varying(50)",
                "fid": "integer",
                "population": "integer",
                "siren_epci": "character varying(20)",
                "statut": "character varying(26)",
            },
            "primary_key": ["fid"],
        },
        {
            "name": "collectivite_territoriale",
            "type": "TABLE",
            "attributes": {
                "geom": "geometry(MultiPolygon,4326)",
                "id": "character varying(24)",
                "insee_col": "character varying(5)",
                "nom": "character varying(200)",
                "nom_m": "character varying(200)",
                "fid": "integer",
            },
            "primary_key": ["fid"],
        },
        {
            "name": "cheflieu_commune",
            "type": "TABLE",
            "attributes": {
                "geom": "geometry(Point,4326)",
                "id": "character varying(24)",
                "id_com": "character varying(24)",
                "nom": "character varying(120)",
                "fid": "integer",
            },
            "primary_key": ["fid"],
        },
        {
            "name": "canton",
            "type": "TABLE",
            "attributes": {
                "geom": "geometry(MultiPolygon,4326)",
                "id": "character varying(24)",
                "insee_can": "character varying(5)",
                "insee_dep": "character varying(3)",
                "insee_reg": "character varying(2)",
                "fid": "integer",
            },
            "primary_key": ["fid"],
        },
        {
            "name": "arrondissement",
            "type": "TABLE",
            "attributes": {
                "geom": "geometry(MultiPolygon,4326)",
                "id": "character varying(24)",
                "insee_arr": "character varying(1)",
                "insee_dep": "character varying(3)",
                "insee_reg": "character varying(2)",
                "nom": "character varying(200)",
                "nom_m": "character varying(200)",
                "fid": "integer",
            },
            "primary_key": ["fid"],
        },
    ]

    expected_stored_data_extent = {
        "geometry": {
            "coordinates": [
                [
                    [
                        [-61.193847656, 14.705322266],
                        [-61.193847656, 14.716296387],
                        [-61.193847656, 14.727270508],
                        [-61.182861328, 14.727270508],
                        [-61.182861328, 14.738244629],
                        [-61.182861328, 14.74921875],
                        [-61.193847656, 14.74921875],
                        [-61.193847656, 14.760192871],
                        [-61.204833984, 14.760192871],
                        [-61.204833984, 14.771166992],
                        [-61.215820312, 14.771166992],
                        [-61.215820312, 14.782141113],
                        [-61.226806641, 14.782141113],
                        [-61.226806641, 14.793115234],
                        [-61.237792969, 14.793115234],
                        [-61.237792969, 14.804089355],
                        [-61.237792969, 14.815063477],
                        [-61.237792969, 14.826037598],
                        [-61.237792969, 14.837011719],
                        [-61.226806641, 14.837011719],
                        [-61.226806641, 14.84798584],
                        [-61.215820312, 14.84798584],
                        [-61.215820312, 14.858959961],
                        [-61.215820312, 14.869934082],
                        [-61.204833984, 14.869934082],
                        [-61.193847656, 14.869934082],
                        [-61.193847656, 14.880908203],
                        [-61.182861328, 14.880908203],
                        [-61.171875, 14.880908203],
                        [-61.160888672, 14.880908203],
                        [-61.149902344, 14.880908203],
                        [-61.138916016, 14.880908203],
                        [-61.127929688, 14.880908203],
                        [-61.116943359, 14.880908203],
                        [-61.105957031, 14.880908203],
                        [-61.105957031, 14.869934082],
                        [-61.094970703, 14.869934082],
                        [-61.094970703, 14.858959961],
                        [-61.083984375, 14.858959961],
                        [-61.072998047, 14.858959961],
                        [-61.072998047, 14.84798584],
                        [-61.062011719, 14.84798584],
                        [-61.051025391, 14.84798584],
                        [-61.040039062, 14.84798584],
                        [-61.040039062, 14.837011719],
                        [-61.029052734, 14.837011719],
                        [-61.018066406, 14.837011719],
                        [-61.018066406, 14.826037598],
                        [-61.018066406, 14.815063477],
                        [-61.007080078, 14.815063477],
                        [-60.99609375, 14.815063477],
                        [-60.99609375, 14.804089355],
                        [-60.99609375, 14.793115234],
                        [-60.985107422, 14.793115234],
                        [-60.985107422, 14.782141113],
                        [-60.974121094, 14.782141113],
                        [-60.963134766, 14.782141113],
                        [-60.952148438, 14.782141113],
                        [-60.952148438, 14.771166992],
                        [-60.963134766, 14.771166992],
                        [-60.963134766, 14.760192871],
                        [-60.963134766, 14.74921875],
                        [-60.952148438, 14.74921875],
                        [-60.952148438, 14.760192871],
                        [-60.941162109, 14.760192871],
                        [-60.941162109, 14.771166992],
                        [-60.930175781, 14.771166992],
                        [-60.919189453, 14.771166992],
                        [-60.908203125, 14.771166992],
                        [-60.897216797, 14.771166992],
                        [-60.897216797, 14.782141113],
                        [-60.886230469, 14.782141113],
                        [-60.875244141, 14.782141113],
                        [-60.864257812, 14.782141113],
                        [-60.864257812, 14.771166992],
                        [-60.864257812, 14.760192871],
                        [-60.864257812, 14.74921875],
                        [-60.875244141, 14.74921875],
                        [-60.886230469, 14.74921875],
                        [-60.886230469, 14.738244629],
                        [-60.886230469, 14.727270508],
                        [-60.897216797, 14.727270508],
                        [-60.908203125, 14.727270508],
                        [-60.919189453, 14.727270508],
                        [-60.919189453, 14.716296387],
                        [-60.908203125, 14.716296387],
                        [-60.908203125, 14.705322266],
                        [-60.897216797, 14.705322266],
                        [-60.886230469, 14.705322266],
                        [-60.875244141, 14.705322266],
                        [-60.875244141, 14.694348145],
                        [-60.875244141, 14.683374023],
                        [-60.875244141, 14.672399902],
                        [-60.875244141, 14.661425781],
                        [-60.875244141, 14.65045166],
                        [-60.886230469, 14.65045166],
                        [-60.886230469, 14.639477539],
                        [-60.875244141, 14.639477539],
                        [-60.875244141, 14.628503418],
                        [-60.864257812, 14.628503418],
                        [-60.864257812, 14.639477539],
                        [-60.853271484, 14.639477539],
                        [-60.842285156, 14.639477539],
                        [-60.842285156, 14.628503418],
                        [-60.842285156, 14.617529297],
                        [-60.842285156, 14.606555176],
                        [-60.853271484, 14.606555176],
                        [-60.853271484, 14.595581055],
                        [-60.842285156, 14.595581055],
                        [-60.842285156, 14.584606934],
                        [-60.831298828, 14.584606934],
                        [-60.831298828, 14.573632813],
                        [-60.8203125, 14.573632813],
                        [-60.8203125, 14.562658691],
                        [-60.8203125, 14.55168457],
                        [-60.8203125, 14.540710449],
                        [-60.8203125, 14.529736328],
                        [-60.8203125, 14.518762207],
                        [-60.8203125, 14.507788086],
                        [-60.8203125, 14.496813965],
                        [-60.809326172, 14.496813965],
                        [-60.809326172, 14.485839844],
                        [-60.809326172, 14.474865723],
                        [-60.809326172, 14.463891602],
                        [-60.809326172, 14.45291748],
                        [-60.809326172, 14.441943359],
                        [-60.8203125, 14.441943359],
                        [-60.8203125, 14.430969238],
                        [-60.8203125, 14.419995117],
                        [-60.8203125, 14.409020996],
                        [-60.831298828, 14.409020996],
                        [-60.842285156, 14.409020996],
                        [-60.842285156, 14.398046875],
                        [-60.853271484, 14.398046875],
                        [-60.853271484, 14.387072754],
                        [-60.864257812, 14.387072754],
                        [-60.875244141, 14.387072754],
                        [-60.886230469, 14.387072754],
                        [-60.886230469, 14.398046875],
                        [-60.886230469, 14.409020996],
                        [-60.897216797, 14.409020996],
                        [-60.897216797, 14.419995117],
                        [-60.897216797, 14.430969238],
                        [-60.886230469, 14.430969238],
                        [-60.886230469, 14.441943359],
                        [-60.897216797, 14.441943359],
                        [-60.908203125, 14.441943359],
                        [-60.908203125, 14.45291748],
                        [-60.919189453, 14.45291748],
                        [-60.919189453, 14.463891602],
                        [-60.930175781, 14.463891602],
                        [-60.930175781, 14.45291748],
                        [-60.941162109, 14.45291748],
                        [-60.941162109, 14.463891602],
                        [-60.952148438, 14.463891602],
                        [-60.963134766, 14.463891602],
                        [-60.974121094, 14.463891602],
                        [-60.985107422, 14.463891602],
                        [-60.99609375, 14.463891602],
                        [-61.007080078, 14.463891602],
                        [-61.018066406, 14.463891602],
                        [-61.018066406, 14.474865723],
                        [-61.029052734, 14.474865723],
                        [-61.029052734, 14.463891602],
                        [-61.040039062, 14.463891602],
                        [-61.040039062, 14.45291748],
                        [-61.029052734, 14.45291748],
                        [-61.029052734, 14.441943359],
                        [-61.029052734, 14.430969238],
                        [-61.040039062, 14.430969238],
                        [-61.040039062, 14.441943359],
                        [-61.051025391, 14.441943359],
                        [-61.051025391, 14.45291748],
                        [-61.062011719, 14.45291748],
                        [-61.072998047, 14.45291748],
                        [-61.072998047, 14.463891602],
                        [-61.083984375, 14.463891602],
                        [-61.083984375, 14.474865723],
                        [-61.083984375, 14.485839844],
                        [-61.094970703, 14.485839844],
                        [-61.094970703, 14.496813965],
                        [-61.105957031, 14.496813965],
                        [-61.105957031, 14.507788086],
                        [-61.105957031, 14.518762207],
                        [-61.105957031, 14.529736328],
                        [-61.094970703, 14.529736328],
                        [-61.094970703, 14.540710449],
                        [-61.083984375, 14.540710449],
                        [-61.083984375, 14.55168457],
                        [-61.072998047, 14.55168457],
                        [-61.062011719, 14.55168457],
                        [-61.062011719, 14.562658691],
                        [-61.051025391, 14.562658691],
                        [-61.040039062, 14.562658691],
                        [-61.029052734, 14.562658691],
                        [-61.029052734, 14.55168457],
                        [-61.018066406, 14.55168457],
                        [-61.007080078, 14.55168457],
                        [-61.007080078, 14.562658691],
                        [-61.018066406, 14.562658691],
                        [-61.018066406, 14.573632813],
                        [-61.029052734, 14.573632813],
                        [-61.029052734, 14.584606934],
                        [-61.040039062, 14.584606934],
                        [-61.051025391, 14.584606934],
                        [-61.062011719, 14.584606934],
                        [-61.062011719, 14.595581055],
                        [-61.072998047, 14.595581055],
                        [-61.083984375, 14.595581055],
                        [-61.094970703, 14.595581055],
                        [-61.105957031, 14.595581055],
                        [-61.105957031, 14.606555176],
                        [-61.105957031, 14.617529297],
                        [-61.116943359, 14.617529297],
                        [-61.127929688, 14.617529297],
                        [-61.127929688, 14.628503418],
                        [-61.138916016, 14.628503418],
                        [-61.149902344, 14.628503418],
                        [-61.149902344, 14.639477539],
                        [-61.160888672, 14.639477539],
                        [-61.160888672, 14.65045166],
                        [-61.160888672, 14.661425781],
                        [-61.171875, 14.661425781],
                        [-61.171875, 14.672399902],
                        [-61.182861328, 14.672399902],
                        [-61.182861328, 14.683374023],
                        [-61.182861328, 14.694348145],
                        [-61.193847656, 14.694348145],
                        [-61.193847656, 14.705322266],
                    ],
                    [
                        [-60.919189453, 14.738244629],
                        [-60.930175781, 14.738244629],
                        [-60.930175781, 14.727270508],
                        [-60.919189453, 14.727270508],
                        [-60.919189453, 14.738244629],
                    ],
                    [
                        [-60.919189453, 14.672399902],
                        [-60.908203125, 14.672399902],
                        [-60.897216797, 14.672399902],
                        [-60.886230469, 14.672399902],
                        [-60.886230469, 14.683374023],
                        [-60.897216797, 14.683374023],
                        [-60.908203125, 14.683374023],
                        [-60.919189453, 14.683374023],
                        [-60.919189453, 14.672399902],
                    ],
                    [
                        [-60.930175781, 14.672399902],
                        [-60.930175781, 14.661425781],
                        [-60.919189453, 14.661425781],
                        [-60.919189453, 14.672399902],
                        [-60.930175781, 14.672399902],
                    ],
                ]
            ],
            "type": "MultiPolygon",
        },
        "type": "Feature",
    }

    check_output_stored_data_relation_and_extent(
        output_stored_data=output_stored_data,
        expected_stored_data_extent=expected_stored_data_extent,
        expected_stored_data_relations=expected_stored_data_relations,
    )
    drop_output_schema()


def test_cli_help(capsys):
    """Test CLI help."""

    with pytest.raises(SystemExit):
        cli.main(["--help"])

    out, err = capsys.readouterr()

    assert __about__.__cli_usage__ in out
    assert err == ""


def test_cli_version(capsys):
    """Test CLI version."""

    with pytest.raises(SystemExit):
        cli.main(["--version"])

    out, err = capsys.readouterr()

    assert out == f"{__about__.__version__}\n"
    assert err == ""


@mock_s3
def test_cli_run_sql(tmp_path):
    """Test run with sql layer test."""
    init_and_run_processing(tmp_path, "sql", "parameters_sql.json")

    # Check some expected outputs
    result = read_json_file(Path(tmp_path / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "SUCCESS"

    output_stored_data = result["output"]["stored_data"]
    expected_stored_data_relations = [
        {
            "attributes": {
                "gid": "integer",
                "insee": "character varying(5)",
                "is_deleted": "boolean",
                "is_rnu": "boolean",
                "name": "character varying(80)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "municipality",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "du_type": "character varying(4)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "grid_name": "character varying(50)",
                "grid_title": "text",
                "id": "character varying(32)",
                "name": "character varying(50)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "document",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datappro": "character varying(10)",
                "datefin": "character varying(10)",
                "dateref": "character varying(10)",
                "etat": "character varying(2)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idurba": "character varying(30)",
                "interco": "character varying(1)",
                "nomplan": "character varying(80)",
                "nomproc": "character varying(10)",
                "nomreg": "character varying(80)",
                "partition": "character varying(32)",
                "siren": "character varying(9)",
                "siteweb": "character varying(254)",
                "the_geom": "geometry(Geometry,4326)",
                "typedoc": "character varying(4)",
                "typeref": "character varying(15)",
                "urlpe": "character varying(254)",
                "urlplan": "character varying(254)",
                "urlreg": "character varying(254)",
            },
            "name": "doc_urba",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datecog": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "doc_urba_com",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idinfo": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idinfo": "character varying(40)",
                "libelle": "character varying(254)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypeinf": "character varying(2)",
                "stypep": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typeinf": "character varying(2)",
                "typep": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "info_pct",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idinfo": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idinfo": "character varying(40)",
                "libelle": "character varying(254)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypeinf": "character varying(2)",
                "stypep": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typeinf": "character varying(2)",
                "typep": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "info_lin",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idinfo": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idinfo": "character varying(40)",
                "libelle": "character varying(254)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypeinf": "character varying(2)",
                "stypep": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typeinf": "character varying(2)",
                "typep": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "info_surf",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "angle": "integer",
                "datappro": "character varying(10)",
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idpsc": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idpsc": "character varying(40)",
                "libelle": "character varying(254)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypepsc": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typepsc": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "prescription_pct",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datappro": "character varying(10)",
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idpsc": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idpsc": "character varying(40)",
                "libelle": "character varying(254)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypepsc": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typepsc": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "prescription_lin",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datappro": "character varying(10)",
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idpsc": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idpsc": "character varying(40)",
                "libelle": "character varying(300)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypepsc": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typepsc": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "prescription_surf",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datappro": "character varying(10)",
                "datvalid": "character varying(10)",
                "destdomi": "character varying(2)",
                "fermreco": "character varying(3)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idzone": "character varying(40)",
                "libelle": "character varying(254)",
                "libelong": "character varying(254)",
                "nomfic": "character varying(254)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
                "typesect": "character varying(3)",
                "urlfic": "character varying(254)",
            },
            "name": "secteur_cc",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "couleur": "character varying(11)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idhab": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idhab": "character varying(40)",
                "nattrac": "character varying(40)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "habillage_lin",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "couleur": "character varying(11)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idhab": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idhab": "character varying(40)",
                "nattrac": "character varying(40)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "habillage_pct",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "couleur": "character varying(11)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idhab": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idhab": "character varying(40)",
                "nattrac": "character varying(40)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "habillage_surf",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "angle": "integer",
                "couleur": "character varying(11)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idhab": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idhab": "character varying(40)",
                "natecr": "character varying(80)",
                "partition": "character varying(32)",
                "police": "character varying(40)",
                "style": "character varying(40)",
                "taille": "integer",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(80)",
            },
            "name": "habillage_txt",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datappro": "character varying(10)",
                "datvalid": "character varying(10)",
                "destdomi": "character varying(2)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idurba": "character varying(30)",
                "idzone": "character varying(40)",
                "insee": "character varying(5)",
                "lib_idzone": "character varying(40)",
                "libelle": "character varying(12)",
                "libelong": "character varying(300)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
                "typezone": "character varying(3)",
                "urlfic": "character varying(254)",
            },
            "name": "zone_urba",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "partition": "character varying(32)",
                "uuid": "character varying(255)",
            },
            "name": "partition_metadata",
            "primary_key": [],
            "type": "TABLE",
        },
        {
            "attributes": {
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "layer": "character varying(64)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "partition_rasterisation",
            "primary_key": ["partition", "layer"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "partition": "character varying(32)",
                "uuid": "character varying(255)",
            },
            "name": "view_partition_metadata",
            "primary_key": [],
            "type": "VIEW",
        },
    ]

    # No data inserted, extent is None
    expected_stored_data_extent = {
        "type": "Feature",
        "geometry": {"type": "Polygon", "coordinates": []},
    }

    check_output_stored_data_relation_and_extent(
        output_stored_data=output_stored_data,
        expected_stored_data_extent=expected_stored_data_extent,
        expected_stored_data_relations=expected_stored_data_relations,
    )
    drop_output_schema()


@mock_s3
def test_cli_run_fix_1155(tmp_path):
    """Test run with multi-geom failure (fix 1155) test."""
    init_and_run_processing(tmp_path, "fix_1155", "parameters_multi_fail.json")

    # Check some expected outputs
    result = read_json_file(Path(tmp_path / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "TECHNICAL_ERROR"


@mock_s3
def test_ajout_error_table_mismatch(tmp_path):
    """Test run for MODIFYING output stored data and invalid input upload tables"""

    # Create output stored data with table test_bas (test_base in input upload)
    drop_output_schema()
    create_output_schema()
    args = [
        "ogr2ogr",
        "-nln",
        f"{OUTPUT_SCHEMA}.test_bas",
        "-overwrite",
        "-f",
        "Postgresql",
        f"PG:host={HOST} dbname={DBNAME} user={USER} password={PASS} port={PORT}",
        "-lco",
        "FID=ogc_fid",
        "tests/fixtures/data/normal/shp/test_base.shp",
    ]
    subprocess.check_call(args, stderr=subprocess.STDOUT)

    init_and_run_processing(
        tmp_path, "modifying", "parameters_modif.json", drop_schema=False
    )

    # Check some expected outputs
    result = read_json_file(Path(tmp_path / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "TECHNICAL_ERROR"

    drop_output_schema()


@mock_s3
def test_ajout(tmp_path):
    """Test run for MODIFYING output stored data and valid input upload tables"""

    # Create output stored data with table test_bas (test_base in input upload)
    drop_output_schema()
    create_output_schema()
    args = [
        "ogr2ogr",
        "-nln",
        f"{OUTPUT_SCHEMA}.test_base",
        "-overwrite",
        "-f",
        "Postgresql",
        f"PG:host={HOST} dbname={DBNAME} user={USER} password={PASS} port={PORT}",
        "-lco",
        "FID=ogc_fid",
        "tests/fixtures/data/normal/shp/test_base.shp",
    ]
    subprocess.check_call(args, stderr=subprocess.STDOUT)
    init_and_run_processing(
        tmp_path, "modifying", "parameters_modif.json", drop_schema=False
    )

    # Check some expected outputs
    result = read_json_file(Path(tmp_path / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "SUCCESS"

    output_stored_data = result["output"]["stored_data"]
    expected_stored_data_relations = [
        {
            "name": "test_base",
            "type": "TABLE",
            "attributes": {
                "fid": "double precision",
                "insee": "character varying(254)",
                "nom": "character varying(254)",
                "ogc_fid": "integer",
                "prénom": "character varying(254)",
                "wkb_geometry": "geometry(Point,4326)",
            },
            "primary_key": ["ogc_fid"],
        }
    ]
    expected_stored_data_extent = {
        "geometry": {
            "coordinates": [
                [
                    [
                        [-1.246948242, 44.45067749],
                        [-1.246948242, 44.44519043],
                        [-1.252441406, 44.44519043],
                        [-1.252441406, 44.45067749],
                        [-1.246948242, 44.45067749],
                    ]
                ],
                [
                    [
                        [6.646728516, 45.937670898],
                        [6.646728516, 45.932183838],
                        [6.641235352, 45.932183838],
                        [6.641235352, 45.937670898],
                        [6.646728516, 45.937670898],
                    ]
                ],
                [
                    [
                        [0.186767578, 47.995318604],
                        [0.186767578, 47.989831543],
                        [0.181274414, 47.989831543],
                        [0.181274414, 47.995318604],
                        [0.186767578, 47.995318604],
                    ]
                ],
                [
                    [
                        [2.592773438, 48.845812988],
                        [2.592773438, 48.840325928],
                        [2.587280273, 48.840325928],
                        [2.587280273, 48.845812988],
                        [2.592773438, 48.845812988],
                    ]
                ],
            ],
            "type": "MultiPolygon",
        },
        "type": "Feature",
    }

    check_output_stored_data_relation_and_extent(
        output_stored_data=output_stored_data,
        expected_stored_data_extent=expected_stored_data_extent,
        expected_stored_data_relations=expected_stored_data_relations,
    )

    drop_output_schema()


@mock_s3
def test_cli_run_modif_csvt(tmp_path):
    """Test run with sql layer test."""
    init_and_run_processing(tmp_path / "init", "sql", "parameters_sql.json")

    init_and_run_processing(
        tmp_path / "modif",
        "modifying_csvt",
        "parameters_modif_csvt.json",
        drop_schema=False,
    )

    result = read_json_file(Path(tmp_path / "modif" / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "SUCCESS"

    output_stored_data = result["output"]["stored_data"]
    print(output_stored_data)

    expected_stored_data_relations = [
        {
            "attributes": {
                "gid": "integer",
                "insee": "character varying(5)",
                "is_deleted": "boolean",
                "is_rnu": "boolean",
                "name": "character varying(80)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "municipality",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "du_type": "character varying(4)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "grid_name": "character varying(50)",
                "grid_title": "text",
                "id": "character varying(32)",
                "name": "character varying(50)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "document",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datappro": "character varying(10)",
                "datefin": "character varying(10)",
                "dateref": "character varying(10)",
                "etat": "character varying(2)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idurba": "character varying(30)",
                "interco": "character varying(1)",
                "nomplan": "character varying(80)",
                "nomproc": "character varying(10)",
                "nomreg": "character varying(80)",
                "partition": "character varying(32)",
                "siren": "character varying(9)",
                "siteweb": "character varying(254)",
                "the_geom": "geometry(Geometry,4326)",
                "typedoc": "character varying(4)",
                "typeref": "character varying(15)",
                "urlpe": "character varying(254)",
                "urlplan": "character varying(254)",
                "urlreg": "character varying(254)",
            },
            "name": "doc_urba",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datecog": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "doc_urba_com",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idinfo": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idinfo": "character varying(40)",
                "libelle": "character varying(254)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypeinf": "character varying(2)",
                "stypep": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typeinf": "character varying(2)",
                "typep": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "info_pct",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idinfo": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idinfo": "character varying(40)",
                "libelle": "character varying(254)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypeinf": "character varying(2)",
                "stypep": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typeinf": "character varying(2)",
                "typep": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "info_lin",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idinfo": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idinfo": "character varying(40)",
                "libelle": "character varying(254)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypeinf": "character varying(2)",
                "stypep": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typeinf": "character varying(2)",
                "typep": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "info_surf",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "angle": "integer",
                "datappro": "character varying(10)",
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idpsc": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idpsc": "character varying(40)",
                "libelle": "character varying(254)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypepsc": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typepsc": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "prescription_pct",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datappro": "character varying(10)",
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idpsc": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idpsc": "character varying(40)",
                "libelle": "character varying(254)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypepsc": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typepsc": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "prescription_lin",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datappro": "character varying(10)",
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idpsc": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idpsc": "character varying(40)",
                "libelle": "character varying(300)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypepsc": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typepsc": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "prescription_surf",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datappro": "character varying(10)",
                "datvalid": "character varying(10)",
                "destdomi": "character varying(2)",
                "fermreco": "character varying(3)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idzone": "character varying(40)",
                "libelle": "character varying(254)",
                "libelong": "character varying(254)",
                "nomfic": "character varying(254)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
                "typesect": "character varying(3)",
                "urlfic": "character varying(254)",
            },
            "name": "secteur_cc",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "couleur": "character varying(11)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idhab": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idhab": "character varying(40)",
                "nattrac": "character varying(40)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "habillage_lin",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "couleur": "character varying(11)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idhab": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idhab": "character varying(40)",
                "nattrac": "character varying(40)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "habillage_pct",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "couleur": "character varying(11)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idhab": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idhab": "character varying(40)",
                "nattrac": "character varying(40)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "habillage_surf",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "angle": "integer",
                "couleur": "character varying(11)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idhab": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idhab": "character varying(40)",
                "natecr": "character varying(80)",
                "partition": "character varying(32)",
                "police": "character varying(40)",
                "style": "character varying(40)",
                "taille": "integer",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(80)",
            },
            "name": "habillage_txt",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "datappro": "character varying(10)",
                "datvalid": "character varying(10)",
                "destdomi": "character varying(2)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idurba": "character varying(30)",
                "idzone": "character varying(40)",
                "insee": "character varying(5)",
                "lib_idzone": "character varying(40)",
                "libelle": "character varying(12)",
                "libelong": "character varying(300)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
                "typezone": "character varying(3)",
                "urlfic": "character varying(254)",
            },
            "name": "zone_urba",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "partition": "character varying(32)",
                "uuid": "character varying(255)",
            },
            "name": "partition_metadata",
            "primary_key": [],
            "type": "TABLE",
        },
        {
            "attributes": {
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "layer": "character varying(64)",
                "partition": "character varying(32)",
                "the_geom": "geometry(Geometry,4326)",
            },
            "name": "partition_rasterisation",
            "primary_key": ["partition", "layer"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "partition": "character varying(32)",
                "uuid": "character varying(255)",
            },
            "name": "view_partition_metadata",
            "primary_key": [],
            "type": "VIEW",
        },
    ]

    expected_stored_data_extent = {
        "geometry": {
            "coordinates": [
                [
                    [
                        [1.505126953, 45.109124756],
                        [1.505126953, 45.114611816],
                        [1.510620117, 45.114611816],
                        [1.510620117, 45.109124756],
                        [1.505126953, 45.109124756],
                    ]
                ]
            ],
            "type": "MultiPolygon",
        },
        "type": "Feature",
    }

    check_output_stored_data_relation_and_extent(
        output_stored_data=output_stored_data,
        expected_stored_data_extent=expected_stored_data_extent,
        expected_stored_data_relations=expected_stored_data_relations,
    )
    drop_output_schema()


@mock_s3
def test_cli_run_insert_gpu(tmp_path):
    """Test run with sql layer test."""
    init_and_run_processing(tmp_path / "init", "gpu_init", "parameters_gpu_init.json")

    init_and_run_processing(
        tmp_path / "modif",
        "gpu_insert",
        "parameters_gpu_insert.json",
        drop_schema=False,
        extra_args=["-p", "GPU"],
    )

    result = read_json_file(Path(tmp_path / "modif" / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "SUCCESS"

    output_stored_data = result["output"]["stored_data"]

    expected_stored_data_relations = [
        {
            "attributes": {
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idinfo": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idinfo": "character varying(40)",
                "libelle": "character varying(254)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypeinf": "character varying(2)",
                "stypep": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typeinf": "character varying(2)",
                "typep": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "info_surf",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "angle": "integer",
                "datappro": "character varying(10)",
                "datvalid": "character varying(10)",
                "gid": "integer",
                "gpu_doc_id": "character varying(32)",
                "gpu_status": "character varying(16)",
                "gpu_timestamp": "timestamp without time zone",
                "idpsc": "character varying(40)",
                "idurba": "character varying(30)",
                "insee": "character varying(5)",
                "lib_idpsc": "character varying(40)",
                "libelle": "character varying(254)",
                "nomfic": "character varying(80)",
                "partition": "character varying(32)",
                "stypepsc": "character varying(2)",
                "the_geom": "geometry(Geometry,4326)",
                "txt": "character varying(10)",
                "typepsc": "character varying(2)",
                "urlfic": "character varying(254)",
            },
            "name": "prescription_pct",
            "primary_key": ["gid"],
            "type": "TABLE",
        },
    ]

    expected_stored_data_extent = {
        "geometry": {
            "coordinates": [
                [
                    [
                        [1.505126953, 45.076202393],
                        [1.505126953, 45.081689453],
                        [1.499633789, 45.081689453],
                        [1.494140625, 45.081689453],
                        [1.494140625, 45.087176514],
                        [1.494140625, 45.092663574],
                        [1.494140625, 45.098150635],
                        [1.494140625, 45.103637695],
                        [1.494140625, 45.109124756],
                        [1.494140625, 45.114611816],
                        [1.499633789, 45.114611816],
                        [1.505126953, 45.114611816],
                        [1.505126953, 45.120098877],
                        [1.510620117, 45.120098877],
                        [1.510620117, 45.125585938],
                        [1.516113281, 45.125585938],
                        [1.521606445, 45.125585938],
                        [1.521606445, 45.120098877],
                        [1.527099609, 45.120098877],
                        [1.532592773, 45.120098877],
                        [1.532592773, 45.114611816],
                        [1.538085938, 45.114611816],
                        [1.543579102, 45.114611816],
                        [1.543579102, 45.109124756],
                        [1.549072266, 45.109124756],
                        [1.549072266, 45.103637695],
                        [1.549072266, 45.098150635],
                        [1.549072266, 45.092663574],
                        [1.543579102, 45.092663574],
                        [1.538085938, 45.092663574],
                        [1.538085938, 45.087176514],
                        [1.532592773, 45.087176514],
                        [1.532592773, 45.081689453],
                        [1.532592773, 45.076202393],
                        [1.527099609, 45.076202393],
                        [1.527099609, 45.070715332],
                        [1.521606445, 45.070715332],
                        [1.516113281, 45.070715332],
                        [1.510620117, 45.070715332],
                        [1.505126953, 45.070715332],
                        [1.505126953, 45.076202393],
                    ]
                ]
            ],
            "type": "MultiPolygon",
        },
        "type": "Feature",
    }

    check_output_stored_data_relation_and_extent(
        output_stored_data=output_stored_data,
        expected_stored_data_extent=expected_stored_data_extent,
        expected_stored_data_relations=expected_stored_data_relations,
    )
    drop_output_schema()


@mock_s3
def test_cli_fix_3371(tmp_path):
    """Test run with reprojected layer test."""
    init_and_run_processing(tmp_path, "fix_3371", "parameters_fix_3371.json")

    # Check some expected outputs
    result = read_json_file(Path(tmp_path / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "SUCCESS"

    output_stored_data = result["output"]["stored_data"]
    expected_stored_data_relations = [
        {
            "attributes": {"geom": "geometry(LineString,4326)", "idzich": "integer"},
            "name": "test_line",
            "primary_key": ["idzich"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "geom": "geometry(Point,4326)",
                "idzich": "integer",
                "insee": "character varying",
                "nom": "character varying",
                "prénom": "character varying",
            },
            "name": "test_point",
            "primary_key": ["idzich"],
            "type": "TABLE",
        },
        {
            "attributes": {
                "geom": "geometry(Polygon,4326)",
                "idzich": "integer",
                "rvb": "character varying",
            },
            "name": "test_polygon",
            "primary_key": ["idzich"],
            "type": "TABLE",
        },
    ]
    expected_stored_data_extent = {
        "geometry": {
            "coordinates": [
                [
                    [
                        [-1.40625, 44.598828125],
                        [-1.23046875, 44.598828125],
                        [-1.23046875, 44.423242188],
                        [-1.40625, 44.423242188],
                        [-1.40625, 44.598828125],
                    ]
                ],
                [
                    [
                        [1.58203125, 45.301171875],
                        [1.58203125, 45.476757812],
                        [1.7578125, 45.476757812],
                        [1.7578125, 45.65234375],
                        [1.7578125, 45.827929688],
                        [1.58203125, 45.827929688],
                        [1.58203125, 45.65234375],
                        [1.40625, 45.65234375],
                        [1.23046875, 45.65234375],
                        [1.0546875, 45.65234375],
                        [1.0546875, 45.827929688],
                        [1.23046875, 45.827929688],
                        [1.40625, 45.827929688],
                        [1.40625, 46.003515625],
                        [1.23046875, 46.003515625],
                        [1.0546875, 46.003515625],
                        [1.0546875, 46.179101563],
                        [1.23046875, 46.179101563],
                        [1.40625, 46.179101563],
                        [1.40625, 46.3546875],
                        [1.58203125, 46.3546875],
                        [1.7578125, 46.3546875],
                        [1.7578125, 46.530273438],
                        [1.93359375, 46.530273438],
                        [2.109375, 46.530273438],
                        [2.28515625, 46.530273438],
                        [2.4609375, 46.530273438],
                        [2.63671875, 46.530273438],
                        [2.63671875, 46.3546875],
                        [2.8125, 46.3546875],
                        [2.8125, 46.530273438],
                        [2.8125, 46.705859375],
                        [2.8125, 46.881445313],
                        [2.8125, 47.05703125],
                        [2.8125, 47.232617188],
                        [2.8125, 47.408203125],
                        [2.8125, 47.583789062],
                        [2.8125, 47.759375],
                        [2.98828125, 47.759375],
                        [2.98828125, 47.934960938],
                        [2.98828125, 48.110546875],
                        [2.8125, 48.110546875],
                        [2.8125, 48.286132812],
                        [2.8125, 48.46171875],
                        [2.63671875, 48.46171875],
                        [2.4609375, 48.46171875],
                        [2.4609375, 48.286132812],
                        [2.28515625, 48.286132812],
                        [2.28515625, 48.110546875],
                        [2.28515625, 47.934960938],
                        [2.109375, 47.934960938],
                        [2.109375, 47.759375],
                        [2.109375, 47.583789062],
                        [2.109375, 47.408203125],
                        [2.109375, 47.232617188],
                        [1.93359375, 47.232617188],
                        [1.93359375, 47.05703125],
                        [1.7578125, 47.05703125],
                        [1.7578125, 46.881445313],
                        [1.7578125, 46.705859375],
                        [1.58203125, 46.705859375],
                        [1.58203125, 46.530273438],
                        [1.40625, 46.530273438],
                        [1.23046875, 46.530273438],
                        [1.23046875, 46.3546875],
                        [1.0546875, 46.3546875],
                        [0.87890625, 46.3546875],
                        [0.703125, 46.3546875],
                        [0.703125, 46.530273438],
                        [0.52734375, 46.530273438],
                        [0.52734375, 46.705859375],
                        [0.52734375, 46.881445313],
                        [0.52734375, 47.05703125],
                        [0.52734375, 47.232617188],
                        [0.52734375, 47.408203125],
                        [0.52734375, 47.583789062],
                        [0.52734375, 47.759375],
                        [0.52734375, 47.934960938],
                        [0.52734375, 48.110546875],
                        [0.703125, 48.110546875],
                        [0.703125, 48.286132812],
                        [0.703125, 48.46171875],
                        [0.703125, 48.637304688],
                        [0.87890625, 48.637304688],
                        [0.87890625, 48.812890625],
                        [1.0546875, 48.812890625],
                        [1.0546875, 48.988476563],
                        [1.0546875, 49.1640625],
                        [1.23046875, 49.1640625],
                        [1.23046875, 49.339648438],
                        [1.40625, 49.339648438],
                        [1.58203125, 49.339648438],
                        [1.58203125, 49.515234375],
                        [1.7578125, 49.515234375],
                        [1.93359375, 49.515234375],
                        [1.93359375, 49.690820313],
                        [2.109375, 49.690820313],
                        [2.28515625, 49.690820313],
                        [2.4609375, 49.690820313],
                        [2.63671875, 49.690820313],
                        [2.8125, 49.690820313],
                        [2.98828125, 49.690820313],
                        [2.98828125, 49.515234375],
                        [2.98828125, 49.339648438],
                        [3.1640625, 49.339648438],
                        [3.1640625, 49.1640625],
                        [3.1640625, 48.988476563],
                        [3.33984375, 48.988476563],
                        [3.515625, 48.988476563],
                        [3.515625, 49.1640625],
                        [3.515625, 49.339648438],
                        [3.69140625, 49.339648438],
                        [3.69140625, 49.515234375],
                        [3.8671875, 49.515234375],
                        [3.8671875, 49.690820313],
                        [4.04296875, 49.690820313],
                        [4.21875, 49.690820313],
                        [4.39453125, 49.690820313],
                        [4.5703125, 49.690820313],
                        [4.74609375, 49.690820313],
                        [4.921875, 49.690820313],
                        [5.09765625, 49.690820313],
                        [5.2734375, 49.690820313],
                        [5.44921875, 49.690820313],
                        [5.44921875, 49.515234375],
                        [5.625, 49.515234375],
                        [5.80078125, 49.515234375],
                        [5.80078125, 49.339648438],
                        [5.9765625, 49.339648438],
                        [5.9765625, 49.1640625],
                        [6.15234375, 49.1640625],
                        [6.15234375, 48.988476563],
                        [6.328125, 48.988476563],
                        [6.328125, 48.812890625],
                        [6.50390625, 48.812890625],
                        [6.50390625, 48.637304688],
                        [6.50390625, 48.46171875],
                        [6.6796875, 48.46171875],
                        [6.6796875, 48.286132812],
                        [6.6796875, 48.110546875],
                        [6.85546875, 48.110546875],
                        [6.85546875, 47.934960938],
                        [6.85546875, 47.759375],
                        [6.85546875, 47.583789062],
                        [6.85546875, 47.408203125],
                        [6.85546875, 47.232617188],
                        [6.85546875, 47.05703125],
                        [6.85546875, 46.881445313],
                        [6.6796875, 46.881445313],
                        [6.50390625, 46.881445313],
                        [6.328125, 46.881445313],
                        [6.15234375, 46.881445313],
                        [5.9765625, 46.881445313],
                        [5.9765625, 46.705859375],
                        [6.15234375, 46.705859375],
                        [6.328125, 46.705859375],
                        [6.50390625, 46.705859375],
                        [6.50390625, 46.530273438],
                        [6.328125, 46.530273438],
                        [6.15234375, 46.530273438],
                        [5.9765625, 46.530273438],
                        [5.80078125, 46.530273438],
                        [5.80078125, 46.3546875],
                        [5.80078125, 46.179101563],
                        [5.9765625, 46.179101563],
                        [6.15234375, 46.179101563],
                        [6.328125, 46.179101563],
                        [6.50390625, 46.179101563],
                        [6.50390625, 46.003515625],
                        [6.328125, 46.003515625],
                        [6.15234375, 46.003515625],
                        [5.9765625, 46.003515625],
                        [5.80078125, 46.003515625],
                        [5.80078125, 45.827929688],
                        [5.625, 45.827929688],
                        [5.625, 45.65234375],
                        [5.44921875, 45.65234375],
                        [5.2734375, 45.65234375],
                        [5.09765625, 45.65234375],
                        [5.09765625, 45.476757812],
                        [4.921875, 45.476757812],
                        [4.74609375, 45.476757812],
                        [4.74609375, 45.301171875],
                        [4.5703125, 45.301171875],
                        [4.39453125, 45.301171875],
                        [4.39453125, 45.125585938],
                        [4.5703125, 45.125585938],
                        [4.74609375, 45.125585938],
                        [4.74609375, 44.95],
                        [4.74609375, 44.774414062],
                        [4.74609375, 44.598828125],
                        [4.74609375, 44.423242188],
                        [4.74609375, 44.24765625],
                        [4.5703125, 44.24765625],
                        [4.5703125, 44.072070312],
                        [4.5703125, 43.896484375],
                        [4.5703125, 43.720898438],
                        [4.39453125, 43.720898438],
                        [4.21875, 43.720898438],
                        [4.04296875, 43.720898438],
                        [4.04296875, 43.896484375],
                        [3.8671875, 43.896484375],
                        [3.69140625, 43.896484375],
                        [3.69140625, 43.720898438],
                        [3.515625, 43.720898438],
                        [3.33984375, 43.720898438],
                        [3.1640625, 43.720898438],
                        [3.1640625, 43.896484375],
                        [3.1640625, 44.072070312],
                        [3.1640625, 44.24765625],
                        [2.98828125, 44.24765625],
                        [2.98828125, 44.423242188],
                        [2.98828125, 44.598828125],
                        [2.98828125, 44.774414062],
                        [2.98828125, 44.95],
                        [2.8125, 44.95],
                        [2.8125, 45.125585938],
                        [2.63671875, 45.125585938],
                        [2.4609375, 45.125585938],
                        [2.28515625, 45.125585938],
                        [2.109375, 45.125585938],
                        [2.109375, 45.301171875],
                        [1.93359375, 45.301171875],
                        [1.7578125, 45.301171875],
                        [1.7578125, 45.125585938],
                        [1.58203125, 45.125585938],
                        [1.40625, 45.125585938],
                        [1.23046875, 45.125585938],
                        [1.23046875, 45.301171875],
                        [1.40625, 45.301171875],
                        [1.58203125, 45.301171875],
                    ],
                    [
                        [4.39453125, 48.46171875],
                        [4.39453125, 48.286132812],
                        [4.21875, 48.286132812],
                        [4.21875, 48.110546875],
                        [4.39453125, 48.110546875],
                        [4.39453125, 47.934960938],
                        [4.39453125, 47.759375],
                        [4.39453125, 47.583789062],
                        [4.39453125, 47.408203125],
                        [4.5703125, 47.408203125],
                        [4.5703125, 47.232617188],
                        [4.5703125, 47.05703125],
                        [4.5703125, 46.881445313],
                        [4.39453125, 46.881445313],
                        [4.39453125, 46.705859375],
                        [4.5703125, 46.705859375],
                        [4.74609375, 46.705859375],
                        [4.74609375, 46.881445313],
                        [4.921875, 46.881445313],
                        [4.921875, 47.05703125],
                        [5.09765625, 47.05703125],
                        [5.09765625, 46.881445313],
                        [5.2734375, 46.881445313],
                        [5.44921875, 46.881445313],
                        [5.625, 46.881445313],
                        [5.80078125, 46.881445313],
                        [5.80078125, 47.05703125],
                        [5.625, 47.05703125],
                        [5.625, 47.232617188],
                        [5.44921875, 47.232617188],
                        [5.44921875, 47.408203125],
                        [5.44921875, 47.583789062],
                        [5.2734375, 47.583789062],
                        [5.2734375, 47.759375],
                        [5.09765625, 47.759375],
                        [5.09765625, 47.934960938],
                        [5.09765625, 48.110546875],
                        [4.921875, 48.110546875],
                        [4.921875, 48.286132812],
                        [4.74609375, 48.286132812],
                        [4.74609375, 48.46171875],
                        [4.5703125, 48.46171875],
                        [4.39453125, 48.46171875],
                    ],
                ],
                [
                    [
                        [0.3515625, 48.110546875],
                        [0.3515625, 47.934960938],
                        [0.17578125, 47.934960938],
                        [0.17578125, 48.110546875],
                        [0.3515625, 48.110546875],
                    ]
                ],
                [
                    [
                        [5.2734375, 43.369726563],
                        [5.44921875, 43.369726563],
                        [5.44921875, 43.194140625],
                        [5.2734375, 43.194140625],
                        [5.2734375, 43.369726563],
                    ]
                ],
                [
                    [
                        [6.6796875, 46.003515625],
                        [6.6796875, 45.827929688],
                        [6.50390625, 45.827929688],
                        [6.50390625, 46.003515625],
                        [6.6796875, 46.003515625],
                    ]
                ],
            ],
            "type": "MultiPolygon",
        },
        "type": "Feature",
    }

    check_output_stored_data_relation_and_extent(
        output_stored_data=output_stored_data,
        expected_stored_data_extent=expected_stored_data_extent,
        expected_stored_data_relations=expected_stored_data_relations,
    )
    drop_output_schema()


@mock_s3
def test_cli_fix_3338(tmp_path):
    """Test run with reprojected layer test."""
    init_and_run_processing(tmp_path, "fix_3338", "parameters_fix_3338.json")

    init_and_run_processing(
        tmp_path, "fix_3338", "parameters_fix_3338_modif.json", drop_schema=False
    )

    # Check some expected outputs
    result = read_json_file(Path(tmp_path / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "SUCCESS"

    output_stored_data = result["output"]["stored_data"]
    expected_stored_data_relations = [
        {
            "attributes": {
                "id": "character varying(254)",
                "ogc_fid": "integer",
                "wkb_geometry": "geometry(MultiPolygon,4326)",
            },
            "name": "multi",
            "primary_key": ["ogc_fid"],
            "type": "TABLE",
        }
    ]
    expected_stored_data_extent = {
        "geometry": {
            "coordinates": [
                [
                    [
                        [-2.98828125, 47.144824219],
                        [-2.98828125, 47.232617188],
                        [-3.076171875, 47.232617188],
                        [-3.076171875, 47.320410156],
                        [-2.98828125, 47.320410156],
                        [-2.98828125, 47.408203125],
                        [-2.900390625, 47.408203125],
                        [-2.8125, 47.408203125],
                        [-2.8125, 47.495996094],
                        [-2.724609375, 47.495996094],
                        [-2.63671875, 47.495996094],
                        [-2.548828125, 47.495996094],
                        [-2.548828125, 47.408203125],
                        [-2.4609375, 47.408203125],
                        [-2.4609375, 47.320410156],
                        [-2.373046875, 47.320410156],
                        [-2.373046875, 47.232617188],
                        [-2.28515625, 47.232617188],
                        [-2.28515625, 47.144824219],
                        [-2.28515625, 47.05703125],
                        [-2.373046875, 47.05703125],
                        [-2.4609375, 47.05703125],
                        [-2.4609375, 46.969238281],
                        [-2.548828125, 46.969238281],
                        [-2.63671875, 46.969238281],
                        [-2.724609375, 46.969238281],
                        [-2.8125, 46.969238281],
                        [-2.8125, 47.05703125],
                        [-2.900390625, 47.05703125],
                        [-2.900390625, 47.144824219],
                        [-2.98828125, 47.144824219],
                    ],
                ],
                [
                    [
                        [-2.4609375, 47.759375],
                        [-2.4609375, 47.847167969],
                        [-2.548828125, 47.847167969],
                        [-2.548828125, 47.934960938],
                        [-2.63671875, 47.934960938],
                        [-2.63671875, 48.022753906],
                        [-2.63671875, 48.110546875],
                        [-2.548828125, 48.110546875],
                        [-2.4609375, 48.110546875],
                        [-2.373046875, 48.110546875],
                        [-2.28515625, 48.110546875],
                        [-2.28515625, 48.198339844],
                        [-2.197265625, 48.198339844],
                        [-2.109375, 48.198339844],
                        [-2.021484375, 48.198339844],
                        [-1.93359375, 48.198339844],
                        [-1.845703125, 48.198339844],
                        [-1.7578125, 48.198339844],
                        [-1.669921875, 48.198339844],
                        [-1.669921875, 48.110546875],
                        [-1.669921875, 48.022753906],
                        [-1.58203125, 48.022753906],
                        [-1.58203125, 47.934960938],
                        [-1.58203125, 47.847167969],
                        [-1.669921875, 47.847167969],
                        [-1.669921875, 47.759375],
                        [-1.7578125, 47.759375],
                        [-1.7578125, 47.671582031],
                        [-1.845703125, 47.671582031],
                        [-1.93359375, 47.671582031],
                        [-2.021484375, 47.671582031],
                        [-2.021484375, 47.583789062],
                        [-2.109375, 47.583789062],
                        [-2.197265625, 47.583789062],
                        [-2.28515625, 47.583789062],
                        [-2.373046875, 47.583789062],
                        [-2.373046875, 47.671582031],
                        [-2.4609375, 47.671582031],
                        [-2.4609375, 47.759375],
                    ],
                ],
                [
                    [
                        [-1.7578125, 48.637304688],
                        [-1.7578125, 48.725097656],
                        [-1.7578125, 48.812890625],
                        [-1.7578125, 48.900683594],
                        [-1.669921875, 48.900683594],
                        [-1.669921875, 48.988476563],
                        [-1.58203125, 48.988476563],
                        [-1.58203125, 49.076269531],
                        [-1.494140625, 49.076269531],
                        [-1.40625, 49.076269531],
                        [-1.318359375, 49.076269531],
                        [-1.318359375, 49.1640625],
                        [-1.23046875, 49.1640625],
                        [-1.142578125, 49.1640625],
                        [-1.0546875, 49.1640625],
                        [-0.966796875, 49.1640625],
                        [-0.966796875, 49.076269531],
                        [-0.87890625, 49.076269531],
                        [-0.87890625, 48.988476563],
                        [-0.791015625, 48.988476563],
                        [-0.703125, 48.988476563],
                        [-0.703125, 48.900683594],
                        [-0.615234375, 48.900683594],
                        [-0.615234375, 48.812890625],
                        [-0.52734375, 48.812890625],
                        [-0.52734375, 48.725097656],
                        [-0.615234375, 48.725097656],
                        [-0.615234375, 48.637304688],
                        [-0.703125, 48.637304688],
                        [-0.703125, 48.549511719],
                        [-0.791015625, 48.549511719],
                        [-0.791015625, 48.46171875],
                        [-0.87890625, 48.46171875],
                        [-0.966796875, 48.46171875],
                        [-0.966796875, 48.373925781],
                        [-1.0546875, 48.373925781],
                        [-1.142578125, 48.373925781],
                        [-1.23046875, 48.373925781],
                        [-1.318359375, 48.373925781],
                        [-1.40625, 48.373925781],
                        [-1.40625, 48.46171875],
                        [-1.494140625, 48.46171875],
                        [-1.58203125, 48.46171875],
                        [-1.58203125, 48.549511719],
                        [-1.669921875, 48.549511719],
                        [-1.669921875, 48.637304688],
                        [-1.7578125, 48.637304688],
                    ],
                ],
                [
                    [
                        [-0.791015625, 46.530273438],
                        [-0.791015625, 46.618066406],
                        [-0.791015625, 46.705859375],
                        [-0.791015625, 46.793652344],
                        [-0.703125, 46.793652344],
                        [-0.703125, 46.881445313],
                        [-0.615234375, 46.881445313],
                        [-0.615234375, 46.969238281],
                        [-0.52734375, 46.969238281],
                        [-0.52734375, 47.05703125],
                        [-0.52734375, 47.144824219],
                        [-0.439453125, 47.144824219],
                        [-0.3515625, 47.144824219],
                        [-0.263671875, 47.144824219],
                        [-0.17578125, 47.144824219],
                        [-0.087890625, 47.144824219],
                        [-0.087890625, 47.05703125],
                        [0, 47.05703125],
                        [0.087890625, 47.05703125],
                        [0.087890625, 46.969238281],
                        [0.17578125, 46.969238281],
                        [0.17578125, 46.881445313],
                        [0.263671875, 46.881445313],
                        [0.263671875, 46.793652344],
                        [0.3515625, 46.793652344],
                        [0.3515625, 46.705859375],
                        [0.3515625, 46.618066406],
                        [0.3515625, 46.530273438],
                        [0.263671875, 46.530273438],
                        [0.263671875, 46.442480469],
                        [0.17578125, 46.442480469],
                        [0.17578125, 46.3546875],
                        [0.087890625, 46.3546875],
                        [0.087890625, 46.266894531],
                        [0.087890625, 46.179101563],
                        [0, 46.179101563],
                        [0, 46.091308594],
                        [-0.087890625, 46.091308594],
                        [-0.087890625, 46.003515625],
                        [-0.17578125, 46.003515625],
                        [-0.263671875, 46.003515625],
                        [-0.263671875, 46.091308594],
                        [-0.3515625, 46.091308594],
                        [-0.439453125, 46.091308594],
                        [-0.52734375, 46.091308594],
                        [-0.52734375, 46.179101563],
                        [-0.615234375, 46.179101563],
                        [-0.703125, 46.179101563],
                        [-0.791015625, 46.179101563],
                        [-0.791015625, 46.266894531],
                        [-0.791015625, 46.3546875],
                        [-0.791015625, 46.442480469],
                        [-0.791015625, 46.530273438],
                    ],
                ],
                [
                    [
                        [-0.439453125, 47.671582031],
                        [-0.439453125, 47.759375],
                        [-0.3515625, 47.759375],
                        [-0.263671875, 47.759375],
                        [-0.263671875, 47.847167969],
                        [-0.17578125, 47.847167969],
                        [-0.17578125, 47.934960938],
                        [-0.087890625, 47.934960938],
                        [-0.087890625, 48.022753906],
                        [0, 48.022753906],
                        [0, 48.110546875],
                        [0.087890625, 48.110546875],
                        [0.087890625, 48.198339844],
                        [0.17578125, 48.198339844],
                        [0.263671875, 48.198339844],
                        [0.263671875, 48.286132812],
                        [0.3515625, 48.286132812],
                        [0.3515625, 48.198339844],
                        [0.439453125, 48.198339844],
                        [0.52734375, 48.198339844],
                        [0.52734375, 48.110546875],
                        [0.615234375, 48.110546875],
                        [0.703125, 48.110546875],
                        [0.791015625, 48.110546875],
                        [0.791015625, 48.022753906],
                        [0.87890625, 48.022753906],
                        [0.87890625, 47.934960938],
                        [0.966796875, 47.934960938],
                        [0.966796875, 47.847167969],
                        [1.0546875, 47.847167969],
                        [1.0546875, 47.759375],
                        [1.142578125, 47.759375],
                        [1.142578125, 47.671582031],
                        [1.23046875, 47.671582031],
                        [1.23046875, 47.583789062],
                        [1.318359375, 47.583789062],
                        [1.318359375, 47.495996094],
                        [1.318359375, 47.408203125],
                        [1.23046875, 47.408203125],
                        [1.142578125, 47.408203125],
                        [1.142578125, 47.320410156],
                        [1.0546875, 47.320410156],
                        [0.966796875, 47.320410156],
                        [0.966796875, 47.232617188],
                        [0.87890625, 47.232617188],
                        [0.791015625, 47.232617188],
                        [0.703125, 47.232617188],
                        [0.615234375, 47.232617188],
                        [0.52734375, 47.232617188],
                        [0.439453125, 47.232617188],
                        [0.3515625, 47.232617188],
                        [0.263671875, 47.232617188],
                        [0.17578125, 47.232617188],
                        [0.17578125, 47.320410156],
                        [0.087890625, 47.320410156],
                        [0, 47.320410156],
                        [-0.087890625, 47.320410156],
                        [-0.17578125, 47.320410156],
                        [-0.17578125, 47.408203125],
                        [-0.263671875, 47.408203125],
                        [-0.3515625, 47.408203125],
                        [-0.3515625, 47.495996094],
                        [-0.439453125, 47.495996094],
                        [-0.52734375, 47.495996094],
                        [-0.52734375, 47.583789062],
                        [-0.52734375, 47.671582031],
                        [-0.439453125, 47.671582031],
                    ],
                ],
                [
                    [
                        [0.087890625, 48.900683594],
                        [0.17578125, 48.900683594],
                        [0.263671875, 48.900683594],
                        [0.3515625, 48.900683594],
                        [0.439453125, 48.900683594],
                        [0.52734375, 48.900683594],
                        [0.615234375, 48.900683594],
                        [0.703125, 48.900683594],
                        [0.791015625, 48.900683594],
                        [0.87890625, 48.900683594],
                        [0.87890625, 48.812890625],
                        [0.87890625, 48.725097656],
                        [0.87890625, 48.637304688],
                        [0.791015625, 48.637304688],
                        [0.703125, 48.637304688],
                        [0.703125, 48.549511719],
                        [0.615234375, 48.549511719],
                        [0.52734375, 48.549511719],
                        [0.52734375, 48.46171875],
                        [0.439453125, 48.46171875],
                        [0.3515625, 48.46171875],
                        [0.263671875, 48.46171875],
                        [0.17578125, 48.46171875],
                        [0.087890625, 48.46171875],
                        [0.087890625, 48.549511719],
                        [0.087890625, 48.637304688],
                        [0.087890625, 48.725097656],
                        [0.087890625, 48.812890625],
                        [0.087890625, 48.900683594],
                    ],
                ],
            ],
            "type": "MultiPolygon",
        },
        "type": "Feature",
    }

    check_output_stored_data_relation_and_extent(
        output_stored_data=output_stored_data,
        expected_stored_data_extent=expected_stored_data_extent,
        expected_stored_data_relations=expected_stored_data_relations,
    )
    drop_output_schema()


@mock_s3
def test_cli_fix_4053(tmp_path):
    """Test run with reprojected layer test."""
    init_and_run_processing(tmp_path, "fix_4053", "parameters_fix_4053.json")

    # Check some expected outputs
    result = read_json_file(Path(tmp_path / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "SUCCESS"

    output_stored_data = result["output"]["stored_data"]
    expected_stored_data_relations = [
        {
            "attributes": {
                "cconac_l": "character varying",
                "cconactxt_l": "character varying",
                "dept": "character varying(2)",
                "fid": "integer",
                "geom": "geometry(MultiPolygon,4326)",
                "gid": "bigint",
                "idcom": "character varying(5)",
                "idcomtxt": "character varying(45)",
                "pk_init": "integer",
                "proba_plainpied": "character varying(3)",
                "secteur_stationnement": "character varying",
                "source": "character varying(20)",
                "surf_parking": "bigint",
                "type_proprio": "character varying(10)",
            },
            "name": "uf_parkings_wgs84_fr_metro_om.gpkg",
            "primary_key": ["fid"],
            "type": "TABLE",
        }
    ]
    expected_stored_data_extent = {
        "geometry": {
            "coordinates": [
                [
                    [
                        [-1.175537109, 44.384832764],
                        [-1.175537109, 44.390319824],
                        [-1.175537109, 44.395806885],
                        [-1.170043945, 44.395806885],
                        [-1.170043945, 44.401293945],
                        [-1.164550781, 44.401293945],
                        [-1.164550781, 44.406781006],
                        [-1.170043945, 44.406781006],
                        [-1.175537109, 44.406781006],
                        [-1.175537109, 44.412268066],
                        [-1.170043945, 44.412268066],
                        [-1.164550781, 44.412268066],
                        [-1.159057617, 44.412268066],
                        [-1.159057617, 44.406781006],
                        [-1.153564453, 44.406781006],
                        [-1.153564453, 44.401293945],
                        [-1.148071289, 44.401293945],
                        [-1.148071289, 44.395806885],
                        [-1.153564453, 44.395806885],
                        [-1.153564453, 44.390319824],
                        [-1.159057617, 44.390319824],
                        [-1.159057617, 44.384832764],
                        [-1.164550781, 44.384832764],
                        [-1.170043945, 44.384832764],
                        [-1.170043945, 44.379345703],
                        [-1.175537109, 44.379345703],
                        [-1.175537109, 44.384832764],
                    ],
                ],
                [
                    [
                        [-1.25793457, 44.44519043],
                        [-1.25793457, 44.45067749],
                        [-1.252441406, 44.45067749],
                        [-1.252441406, 44.44519043],
                        [-1.246948242, 44.44519043],
                        [-1.241455078, 44.44519043],
                        [-1.235961914, 44.44519043],
                        [-1.235961914, 44.439703369],
                        [-1.235961914, 44.434216309],
                        [-1.241455078, 44.434216309],
                        [-1.246948242, 44.434216309],
                        [-1.252441406, 44.434216309],
                        [-1.252441406, 44.439703369],
                        [-1.25793457, 44.439703369],
                        [-1.25793457, 44.44519043],
                    ],
                ],
                [
                    [
                        [-1.197509766, 44.44519043],
                        [-1.192016602, 44.44519043],
                        [-1.186523438, 44.44519043],
                        [-1.186523438, 44.439703369],
                        [-1.192016602, 44.439703369],
                        [-1.197509766, 44.439703369],
                        [-1.197509766, 44.44519043],
                    ],
                ],
                [
                    [
                        [-1.241455078, 44.461651611],
                        [-1.235961914, 44.461651611],
                        [-1.235961914, 44.456164551],
                        [-1.235961914, 44.45067749],
                        [-1.241455078, 44.45067749],
                        [-1.241455078, 44.456164551],
                        [-1.241455078, 44.461651611],
                    ],
                ],
                [
                    [
                        [-1.213989258, 44.45067749],
                        [-1.213989258, 44.456164551],
                        [-1.213989258, 44.461651611],
                        [-1.208496094, 44.461651611],
                        [-1.20300293, 44.461651611],
                        [-1.20300293, 44.456164551],
                        [-1.197509766, 44.456164551],
                        [-1.197509766, 44.45067749],
                        [-1.20300293, 44.45067749],
                        [-1.208496094, 44.45067749],
                        [-1.213989258, 44.45067749],
                    ],
                ],
                [
                    [
                        [-1.20300293, 44.461651611],
                        [-1.20300293, 44.467138672],
                        [-1.197509766, 44.467138672],
                        [-1.192016602, 44.467138672],
                        [-1.192016602, 44.461651611],
                        [-1.197509766, 44.461651611],
                        [-1.20300293, 44.461651611],
                    ],
                ],
                [
                    [
                        [-1.153564453, 44.384832764],
                        [-1.153564453, 44.390319824],
                        [-1.148071289, 44.390319824],
                        [-1.142578125, 44.390319824],
                        [-1.137084961, 44.390319824],
                        [-1.137084961, 44.384832764],
                        [-1.131591797, 44.384832764],
                        [-1.131591797, 44.379345703],
                        [-1.137084961, 44.379345703],
                        [-1.137084961, 44.373858643],
                        [-1.142578125, 44.373858643],
                        [-1.142578125, 44.379345703],
                        [-1.148071289, 44.379345703],
                        [-1.153564453, 44.379345703],
                        [-1.159057617, 44.379345703],
                        [-1.159057617, 44.384832764],
                        [-1.153564453, 44.384832764],
                    ],
                ],
                [
                    [
                        [-1.164550781, 44.423242188],
                        [-1.164550781, 44.428729248],
                        [-1.170043945, 44.428729248],
                        [-1.170043945, 44.434216309],
                        [-1.164550781, 44.434216309],
                        [-1.164550781, 44.439703369],
                        [-1.159057617, 44.439703369],
                        [-1.153564453, 44.439703369],
                        [-1.148071289, 44.439703369],
                        [-1.148071289, 44.434216309],
                        [-1.153564453, 44.434216309],
                        [-1.153564453, 44.428729248],
                        [-1.153564453, 44.423242188],
                        [-1.153564453, 44.417755127],
                        [-1.159057617, 44.417755127],
                        [-1.164550781, 44.417755127],
                        [-1.164550781, 44.423242188],
                    ],
                ],
                [
                    [
                        [-1.131591797, 44.434216309],
                        [-1.131591797, 44.428729248],
                        [-1.137084961, 44.428729248],
                        [-1.137084961, 44.434216309],
                        [-1.131591797, 44.434216309],
                    ],
                ],
                [
                    [
                        [-1.137084961, 44.467138672],
                        [-1.131591797, 44.467138672],
                        [-1.126098633, 44.467138672],
                        [-1.120605469, 44.467138672],
                        [-1.120605469, 44.461651611],
                        [-1.120605469, 44.456164551],
                        [-1.126098633, 44.456164551],
                        [-1.131591797, 44.456164551],
                        [-1.137084961, 44.456164551],
                        [-1.137084961, 44.461651611],
                        [-1.137084961, 44.467138672],
                    ],
                ],
            ],
            "type": "MultiPolygon",
        },
        "type": "Feature",
    }

    check_output_stored_data_relation_and_extent(
        output_stored_data=output_stored_data,
        expected_stored_data_extent=expected_stored_data_extent,
        expected_stored_data_relations=expected_stored_data_relations,
    )
    drop_output_schema()


@mock_s3
def test_cli_fix_4046(tmp_path):
    """Test run with reprojected layer test."""
    init_and_run_processing(tmp_path, "fix_4053", "parameters_fix_4046.json")

    # Check some expected outputs
    result = read_json_file(Path(tmp_path / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "SUCCESS"

    output_stored_data = result["output"]["stored_data"]
    expected_stored_data_relations = [
        {
            "attributes": {
                "cconac_l": "character varying",
                "cconactxt_l": "character varying",
                "dept": "character varying(2)",
                "fid": "integer",
                "geom": "geometry(MultiPolygon,4326)",
                "gid": "bigint",
                "idcom": "character varying(5)",
                "idcomtxt": "character varying(45)",
                "pk_init": "integer",
                "proba_plainpied": "character varying(3)",
                "secteur_stationnement": "character varying",
                "source": "character varying(20)",
                "surf_parking": "bigint",
                "type_proprio": "character varying(10)",
            },
            "name": "uf_parkings_wgs84_fr_metro_om.gpkg",
            "primary_key": ["fid"],
            "type": "TABLE",
        }
    ]

    check_output_stored_data_relation_and_extent(
        output_stored_data=output_stored_data,
        expected_stored_data_extent=None,
        expected_stored_data_relations=expected_stored_data_relations,
    )
    drop_output_schema()


@mock_s3
def test_cli_fix_explgpf_54(tmp_path):
    """Test run with reprojected layer test."""
    drop_output_schema()
    with psycopg.connect(
        host=HOST, dbname=DBNAME, user=USER, password=PASS, port=PORT
    ) as con:
        con.cursor().execute(f"CREATE SCHEMA IF NOT EXISTS {OUTPUT_SCHEMA};")
        con.cursor().execute(
            f'CREATE TABLE IF NOT EXISTS {OUTPUT_SCHEMA}.detection ("fid" bigint PRIMARY KEY GENERATED BY DEFAULT AS IDENTITY, "id_namr" bigint UNIQUE, "farm_centroid_longitude" decimal(15, 8), "farm_centroid_latitude" decimal(15, 8), "farm_area" decimal(15, 2), "nb_panel" int, "nb_construction" int, "municipality_code_list" char(5) ARRAY, "municipality_name_list" text ARRAY, "millesime" int, "last_detection_update" timestamp, "geom" geometry(MULTIPOLYGON,2154));'
        )

    init_and_run_processing(
        tmp_path, "fix_explgpf_54", "parameters_fix_explgpf_54.json", False
    )

    # Check some expected outputs
    result = read_json_file(Path(tmp_path / "output.job_id.json"))
    assert result["pipeline_status"]["gpf-vector-to-db"] == "SUCCESS"
